*This do file imports and saves various raw data files in Stata format. The raw sets of data include raw household, member, and consumption data files.
	
clear all 
set more off
set maxvar 10000
*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}
*Import and label Enumeration areas
*There are 143 Enumeration areas in EA Master.dta.(EA Master is the master sample file)
*20 Enumeration areas were selected from each state, 15 to serve as the sample and 5 to serve as replacement if any of first 15 enumeration areas could not be revisited.
*In Western Equatoria, 5 Enumeration areas could not be visited from the first 15 due to security concerns. 2 of the replacement enumeration areas from WES could also not be visited due to security concerns.
*3 enumeration areas were further selected from WES to serve as replacements. 2 of these were visited and surveyed.
import excel "${gsdDataRaw}\wave_2_sample_compiled.xlsx", clear first
ren (smpl_EA smpl_EA_name) (s_ea s_ea_full)
label variable s_ea "Enumeration area code"
label variable s_ea_full "Enumeration area name"
save "${gsdDataRaw}/General/EA_master.dta", replace

*Import all csv files and save as raw dta files
*Appending the 9 interviews recovered from xml.
import delimited "${gsdDownloads}/South Sudan HFS Wave2 Questionnaire-recovery.csv", bindquote(strict) clear
save "${gsdDataRaw}/hhq_recoveredinterviews.dta", replace
import delimited "${gsdDownloads}/South Sudan HFS Wave2 Questionnaire.csv", bindquote(strict) clear
append using "${gsdDataRaw}/hhq_recoveredinterviews.dta", force 
save "${gsdDataRaw}/hhq.dta", replace
*There are a total of 1304 household level observations in the raw data.

import delimited "${gsdDownloads}/South Sudan HFS Wave2 Questionnaire-mod_b-hhm-recovery.csv", bindquote(strict) clear
save "${gsdDataRaw}/hhm_recoveredinterviews.dta", replace
import delimited "${gsdDownloads}/South Sudan HFS Wave2 Questionnaire-mod_b-hhm.csv", bindquote(strict) clear
append using "${gsdDataRaw}/hhm_recoveredinterviews.dta", force
save "${gsdDataRaw}/hhm.dta", replace

import delimited "${gsdDownloads}/South Sudan HFS Wave2 Questionnaire-mod_b-hhm_names-recovery.csv", bindquote(strict) clear
save "${gsdDataRaw}/hhm_names_recoveredinterviews.dta", replace
import delimited "${gsdDownloads}/South Sudan HFS Wave2 Questionnaire-mod_b-hhm_names.csv", bindquote(strict) clear 
append using "${gsdDataRaw}/hhm_names_recoveredinterviews.dta", force
save "${gsdDataRaw}/hhm_names.dta", replace

import delimited "${gsdDownloads}/South Sudan HFS Wave2 Questionnaire-mod_e-rep_e-recovery.csv", bindquote(strict) clear
save "${gsdDataRaw}/food_recoveredinterviews.dta", replace
import delimited "${gsdDownloads}/South Sudan HFS Wave2 Questionnaire-mod_e-rep_e.csv", bindquote(strict) clear 
append using "${gsdDataRaw}/food_recoveredinterviews.dta", force
save "${gsdDataRaw}/food.dta", replace

import delimited "${gsdDownloads}/South Sudan HFS Wave2 Questionnaire-mod_f-rep_f-recovery.csv", bindquote(strict) clear
save "${gsdDataRaw}/nonfood_recoveredinterviews.dta", replace
import delimited "${gsdDownloads}/South Sudan HFS Wave2 Questionnaire-mod_f-rep_f.csv", bindquote(strict) clear 
append using "${gsdDataRaw}/nonfood_recoveredinterviews.dta", force
save "${gsdDataRaw}/nonfood.dta", replace

import delimited "${gsdDownloads}/South Sudan HFS Wave2 Questionnaire-mod_g-rep_g-recovery.csv", bindquote(strict) clear
save "${gsdDataRaw}/livestock_recoveredinterviews.dta", replace
import delimited "${gsdDownloads}/South Sudan HFS Wave2 Questionnaire-mod_g-rep_g.csv", bindquote(strict) clear 
append using "${gsdDataRaw}/livestock_recoveredinterviews.dta", force
save "${gsdDataRaw}/livestock.dta", replace

import delimited "${gsdDownloads}/South Sudan HFS Wave2 Questionnaire-mod_h-rep_h-recovery.csv", bindquote(strict) clear
save "${gsdDataRaw}/assets_recoveredinterviews.dta", replace
import delimited "${gsdDownloads}/South Sudan HFS Wave2 Questionnaire-mod_h-rep_h.csv", bindquote(strict) clear 
append using "${gsdDataRaw}/assets_recoveredinterviews.dta", force
save "${gsdDataRaw}/assets.dta", replace

*Consolidating the sample frame of Wave2 and Wave1:
import delimited "${gsdDownloads}/South Sudan HFS Wave2 Listing Form.csv", bindquote(strict) clear 
*Consolidating ea variable
order ea_v ea_barcode b_v r_ea_3dig 
*ea_barcode has nonnumeric data. Removing non barcode data.
replace ea_barcode = "" if length(ea_barcode)>12
destring ea_barcode, replace
format ea_barcode ea_v %12.0f
gen double ea=ea_v
replace ea=ea_barcode if missing(ea)

*There are still some ea's without any values. For those, I look at the values in b_v and r_ea_3dig
tostring r_ea_12dig, replace format(%13.0f)
tostring b_v r_ea_3dig, replace
replace b_v = "" if b_v == "."
replace r_ea_3dig = "" if r_ea_3dig == "."
replace r_ea_12dig = "" if r_ea_12dig == "."
replace r_ea_12dig = b_v + r_ea_3dig if length(r_ea_12dig) == 11
replace r_ea_12dig = b_v +r_ea_3dig if r_ea_12dig == "910505008112"
assert r_ea_12dig == b_v +r_ea_3dig if !missing(r_ea_12dig) & !missing(r_ea_3dig) & !missing(b_v)
replace r_ea_12dig = "" if r_ea_12dig=="."
destring r_ea_12dig, replace
replace ea=r_ea_12dig if missing(ea)
assert !missing(ea)
assert key == instanceid
ren key parent_key
assert enum_check == 1
*Dropping unnecessary variables
drop ea_v ea_barcode b_v r_ea_3dig qr_id qr_idcheck team_id enum_id team_name enum_check enum_name s_v c_v p_v ea_missing r_payam r_boma r_ea_12dig ea_barcode_yn generated_note_name_38
order enum_identity hh_id_prefix ea
save "${gsdDataRaw}/listing.dta", replace

import delimited "${gsdDownloads}/South Sudan HFS Wave2 Listing Form-hhids.csv", bindquote(strict) clear 
keep parent_key hh_id* hhh_name hh_size loc* hh_add
merge m:1 parent_key using "${gsdDataRaw}/listing.dta", assert(match) nogen
*Saving sample frame for new EAs in Wave2.
save "${gsdDataRaw}/listing_hhids.dta", replace

import delimited "${gsdDownloads}/Household listing form-W1.csv", bindquote(strict) clear
*ea is not clean in the table.
ren s_ea ea
*We clean it by comparison with the EA-Master.dta
tostring r_state r_county r_ea, replace
gen county = substr(r_county ,3,2)
gen ea_clean = r_state + county + "0" + r_ea if length(r_ea) == 7
replace ea_clean = r_state + county + "00" + r_ea if length(r_ea) == 6
destring ea_clean, replace
replace ea = ea_clean if ea == .
drop ea_clean
assert key == instanceid
ren key parent_key
*Some enumeration areas are still missing. There is not enough information in the files for me to assess the enumeration areas.
drop qr_id qr_idcheck team_id enum_team enum_id enum_name enum_check s_state s_county s_payam s_boma r_state r_county r_ea generated_note_name_48 formdef_version county
save "${gsdDataRaw}/listing-W1.dta", replace
import delimited "${gsdDownloads}/Household listing form-hhids-W1.csv", bindquote(strict) clear
keep parent_key hh_id* hhh_name hh_size loc*
merge m:1 parent_key using "${gsdDataRaw}/listing-W1.dta", keep(match) nogen
save "${gsdDataRaw}/listing_hhids-W1.dta", replace
append using "${gsdDataRaw}/listing_hhids.dta"
drop formdef_version isvalidated
order ea enum_identity hh_id* hhh_name hh_size loc*
save "${gsdDataRaw}/listing_hhidsW1W2.dta", replace
