*This do file calculates weights.
*Check if filepaths have been established using init.do
clear all
set more off
set maxvar 10000
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}
*Preparing the Sample Frame
import delimited "${gsdDataRaw}/General/Sample.csv", bindquote(strict) clear
*This sample file contains information about the randomly selected Enumeration Areas. (These enumeration areas were used in addition to the Wave1 urban enumeration areas.)
keep state statecode s_ea households
merge 1:1 s_ea using "${gsdDataRaw}/General/EA_Master.dta", keep(using match) nogen
*Not all EAs are in the Sample are drawn through random selection for Wave2. 88 EAs are matched with the sample file. 55 are yet to be matched.
*Population and Household data for remaining EAs can be drawn from the Wave1 sample frame.
merge 1:m s_ea using "${gsdDataRaw}/General/EA_Master_W1.dta", update keep(master match match_update match_conflict) keepusing(state_drop s_ea_s population households) nogen 
*Consolidating variables
replace statecode = s_ea_s if missing(statecode)
replace state = state_drop if missing(state)
drop s_ea_s state_drop
*Incorporating values for state for 2 EAs that have missing values. These are the two EAs that were added as replacements later.
replace state = substr(s_ea_full,1,3) if missing(state)
replace statecode = 91 if state == "WES"
*Consolidating the values of state
replace state = "Central Equatoria" if state == "CES"
replace state = "Eastern Equatoria" if state == "EES"
replace state = "Lakes" if state == "LKS"
replace state = "Northern Bahr el Ghazal" if state == "NBG"
replace state = "Western Bahr el Ghazal" if state == "WBG"
replace state = "Western Equatoria" if state == "WES"
format s_ea %12.0g
labmask statecode, values(state)
drop state
ren statecode state
save "${gsdTemp}/EA_Master_withmissinghh.dta", replace
*There are still two EAs missing household figures.
import delimited using "${gsdDataRaw}/General/EA_hh.csv", bindquote(strict) clear
merge 1:1 s_ea using "${gsdTemp}/EA_Master_withmissinghh.dta", update nogen
assert !missing(households)
save "${gsdTemp}/EA_Master_withhh.dta", replace
import delimited using "${gsdDataRaw}/General/HH_in_stratum.csv", bindquote(strict) clear
merge 1:m state using "${gsdTemp}/EA_Master_withhh.dta", assert(match) nogen
label var hh_in_stratum "Households in stratum"
gen n_ea_select = 15 
label var n_ea_select "Number of EAs selected in a stratum"
*Calculating probability of selection of an EA: (Number of households in an EA/ Number of households in the EA's stratum)*Number of EAs selected.
gen P1 = (households/hh_in_stratum)*n_ea_select
ren s_ea ea
save "${gsdTemp}/EA_Master_withP1.dta", replace
*Bring in replacement EAs and establish final EA sample with probabilities of selection of an EA.
import excel "${gsdDataRaw}/General/Replacements.xlsx", firstrow clear
merge 1:1 ea using "${gsdTemp}/EA_Master_withP1.dta", keep(master using match)
format ea replacement_ea %12.0g
gen double ea_orig = ea
gen double ea_field = ea
format ea_orig ea_field %12.0g
gen ea_field_full = s_ea_full
replace ea_field = replacement_ea if _merge == 3
replace ea_field_full = replacement_ea_full if _merge == 3
label var ea_orig "EA from sample - used for prob of EA's selection"
label var ea_field "EA from fieldwork (differs because of replacements)"
drop _merge
drop if replacement == 1
save "${gsdTemp}/EA_Master_field_withP1.dta", replace
use "${gsdDataRaw}/listing_hhids.dta", clear
drop if hh_add == 0
bysort ea: gen nhhc = _N
keep ea nhhc
duplicates drop
merge 1:1 ea using "${gsdDataRaw}/General/ea-listing_W1.dta", nogen
rename nhhc nhh_ea_list
rename ea ea_field
merge 1:1 ea_field using  "${gsdTemp}/EA_Master_field_withP1.dta", keep(match using) nogen
replace nhh_ea_list = households if missing(nhh_ea_list) | nhh_ea_list < 30
save "${gsdTemp}/EA_Master_field_withP1andlist.dta", replace
*Calculate number of households surveyed in each EA:
use "${gsdData}/0-RawOutput/hhq.dta", clear
bysort state ea: gen n = _N
collapse n, by(state ea)
ren (ea n) (ea_field nhh_sample)
merge 1:1 ea_field using "${gsdTemp}/EA_Master_field_withP1andlist.dta", keep(match) nogen
ren households nhh_ea_cens
*Calculate sampling weights based on the census and based on the listing
foreach k in cens list {
	*Then calculate probability of HH selection
	gen p2_`k' = nhh_sample / nhh_ea_`k'
	*Next caculate the weight as the inverse joint probability of HH and EA selection
	gen pweight_`k' = 1/(P1 * p2_`k')
	*Next generate sum of weights by state-stratum
	bysort state: egen tot_pweight_`k' = sum(nhh_sample * pweight_`k')
	bysort state: egen xcheck_`k' = total(nhh_sample * pweight_`k')
}
*Check whether census weights sum up correctly to census population
assert (hh_in_stratum == round(xcheck_cens)) if state != 83
*SCALE to conserve population counts per strata but using our listing
gen weight_W2 = pweight_list * tot_pweight_cens / tot_pweight_list
*scaling weight for Western Bahr El Ghazl to match household population. In Western Bahr El Ghazl, 15 EAs were selected, but 11 were finally surveyed.
replace weight_W2 = weight_W2 * (15/11) if state == 83
bysort state: egen xcheck = total(nhh_sample * weight_W2)
assert (hh_in_stratum == round(xcheck))
drop xcheck*
*Keep weights
keep state ea_field weight pweight_cens
label var weight_W2 "Population weight based on listing scaled to Census"
label var pweight_cens "Population weight based Census"
ren ea_field ea
*Save data
save "${gsdTemp}/Weights.dta", replace
*Merge weights into hhq data
*Load hhq data and merge pweights
use "${gsdData}/0-RawOutput/hhq.dta", clear
merge m:1 ea using "${gsdTemp}/Weights.dta", assert(match) keep(match master) keepusing(weight_W2) nogen
*Set Survey data
svyset ea [pweight=weight_W2] , strata(state)
qui tabout state using "${gsdOutput}/Raw-Data 0.xls", svy c(freq) pop replace
save "${gsdData}/0-RawTemp\hhq_withweights.dta", replace
