*This do file
*Extracts the variables state ea and hh and merge them with W2W1MatchedIDs.dta
*Anonymizes the data by generating anonymization keys for enumeration areas, households and enumerators
use "${gsdDataRaw}\Wave1\0-RawOutput\hhq.dta", clear
keep hhuid 
*Merge anonymized household IDs
merge 1:1 hhuid using "${gsdDataRaw}\Wave1\Anonymization Keys\hh_anonkey.dta", assert(match) keep(match master) keepusing(rand hh_anon) nogenerate
merge 1:1 hhuid using "${gsdData}\0-RawOutput\W1W2MatchedIDs.dta", keep(using match) nogen
drop hhuid
save "${gsdTemp}/W1W2MatchedIDs_hh_anon.dta", replace
*Preparing Wave2 files with anonymized ea and hh and enum IDs.
merge 1:1 parent_key using "${gsdData}/0-RawTemp\hhq_withweights.dta", keep(master match using) keepusing(state ea parent_key) nogen
label define lState 81 "Warrap", add
label values state lState
*Incorporating anonymized Enumeration Area IDs.
merge m:1 ea using "${gsdDataRaw}\Wave1\Anonymization Keys\ea_anonkey.dta", keep(match master) keepusing(ea_anon) nogenerate
*Generating random ID for unmatched households in enumeration areas that were surveyed in both Wave1 and Wave2.
keep state ea parent_key ea_anon rand hh_anon
sort state ea parent_key
*Set seed equal to: WB building number (1818) followed by zip code (20433)
set seed 181820433
*Generate random variable 
gen rand1 = runiform() if !missing(ea_anon) & missing(hh_anon)
*Generate anonymized HH ID
bysort state ea: egen hh_anon_W2 = rank(rand1)
*We start the anonymized hh IDs from 13 for the enumeration areas that were covered both in Wave1 and Wave2 so that the hh_anon IDs do not overlap between households in Wave1 and Wave2 except for matched households.
replace hh_anon = hh_anon_W2 + 12 if missing(hh_anon)
drop hh_anon_W2
*Generate random ID for each household in the enumeration areas surveyed only in Wave2.
gen rand2 = runiform() if missing(ea_anon)
*Generate anonymized HH ID
bysort state ea: egen hh_anon_W2 = rank(rand2) if missing(ea_anon)
replace hh_anon= hh_anon_W2 if missing(hh_anon)
drop hh_anon_W2
order state ea
save "${gsdData}/0-RawTemp/hh_anonkey.dta", replace
*Generate random ID for each EA not included in Wave1. 
*Take mean of random variable at the EA level
collapse (mean) rand2, by (state ea ea_anon)
*Generate anonymized EA ID using mean of random variable 
bysort state: egen ea_anon_W2 = rank(rand2)
replace ea_anon = ea_anon_W2 if state == 81
*We start the anonymized enon IDs from 51 for the states that were covered both in Wave1 and Wave2 so that the ea_anon IDs do not overlap between enumeration areas in Wave1 and Wave2 except for the same enumeration areas.
replace ea_anon = ea_anon_W2 + 50 if missing(ea_anon)
drop ea_anon_W2
save "${gsdData}\0-RawTemp\ea_anonkey.dta", replace
*Generate random ID for new enumerators who participated in Wave2 but not in Wave1.
*Preparing enum_anonkeys for merge with Wave2 data.
use "${gsdDataRaw}\Wave1\Anonymization Keys\enum_anonkey.dta"
replace enum_m = strtrim(enum_m)
replace enum_m = upper(enum_m)
save "${gsdTemp}\enum_anonkey_formerge.dta", replace
use "${gsdData}/0-RawOutput/hhq.dta", clear
keep parent_key enum_m
merge 1:1 parent_key using "${gsdData}/0-RawTemp/hh_anonkey.dta", assert(match) keepusing(rand* hh_anon) nogen
merge m:1 enum_m using "${gsdTemp}\enum_anonkey_formerge.dta", keep(master match) keepusing(enum_anon) nogen
replace rand = rand1 if missing(rand)
replace rand = rand2 if missing(rand)
assert !missing(rand)
collapse (mean) rand, by(enum_m enum_anon) 
*Generate anonymized EA ID using mean of random variable
egen enum_anon_W2 = rank(rand) if missing(enum_anon)
*We start new enumerators by 
replace enum_anon = enum_anon_W2 + 27 if missing(enum_anon)
drop enum_anon_W2
save "${gsdData}/0-RawTemp/enum_anonkey.dta", replace
*Anonymize hhq data
use "${gsdData}/0-RawTemp\hhq_withweights.dta", clear
*Merge anonymized household IDs
merge 1:1 parent_key using "${gsdData}/0-RawTemp/hh_anonkey.dta", assert(match) keep(match master) keepusing(hh_anon) nogenerate
*Merge anonymized EA IDs
merge m:1 ea using "${gsdData}/0-RawTemp/ea_anonkey.dta", assert(match) keep(match master) keepusing(ea_anon) nogenerate
*Merge anonymized enumerator IDs
merge m:1 enum_m using "${gsdData}/0-RawTemp/enum_anonkey.dta", assert(match) keep(match master) keepusing(enum_anon) nogenerate
*Drop identifying information
drop ea replace_yn parent_key enum_m  device* subscribe* hhh_name hhr_name r_* loc*
*Rename
rename (ea_anon hh_anon enum_anon) (ea hh enum)
*Sort and reorder
sort state ea hh enum weight_W2
order state ea hh enum 
*Save anonymized hhq data
save "${gsdData}/0-RawTemp/hhq_anon.dta", replace
*Anonymize hhm data
*Load hhm data
use "${gsdData}/0-RawOutput/hhm.dta", clear
*Merge anonymized household IDs
merge m:1 parent_key using "${gsdData}/0-RawTemp/hh_anonkey.dta", assert(match) keep(match master) keepusing(hh_anon) nogenerate
*Merge state and non-anonymized EAs and weights
merge m:1 parent_key using "${gsdData}/0-RawTemp\hhq_withweights.dta" , assert(match) keep(match master) keepusing(state ea) nogenerate
*Merge anonymized EA IDs
merge m:1 ea using "${gsdData}/0-RawTemp/ea_anonkey.dta", assert(match) keep(match master) keepusing(ea_anon) nogenerate
*Drop identifying information
drop ea parent_key member_key *name
*Rename and reorder
rename (ea_anon hh_anon) (ea hh)
order state ea hh hhmid
*Save anonymized hhm data
save "${gsdData}/0-RawTemp/hhm_anon.dta", replace
*Anonymize consumption data
foreach sf in food nonfood livestock assets {
	*Load consumption data
	use "${gsdData}/0-RawOutput/`sf'.dta", clear
	if "`sf'"=="food" | "`sf'"=="nonfood" {
		sort parent_key item_category item_name
		}
	else if "`sf'"=="livestock" {
		sort parent_key rl_index
		}
	else if "`sf'"=="assets" {
		sort parent_key ra_index
		}
	*Merge anonymized household IDs
	merge m:1 parent_key using "${gsdData}/0-RawTemp/hh_anonkey.dta", assert(match) keep(match master) keepusing(hh_anon) nogenerate
	*Merge state and non-anonymized EAs
	merge m:1 parent_key using "${gsdData}/0-RawTemp\hhq_withweights.dta" , assert(match) keep(match master) keepusing(state ea) nogenerate
	*Merge anonymized EA IDs
	merge m:1 ea using "${gsdData}/0-RawTemp/ea_anonkey.dta", assert(match) keep(match master) keepusing(ea_anon) nogenerate
	*Drop identifying information
	drop ea *key
	*Rename and reorder
	rename (ea_anon hh_anon) (ea hh)
	order state ea hh 
	*Save anonymized consumption data
	save "${gsdData}/0-RawTemp/`sf'_anon.dta", replace
}
