* This do file prepares sharable version of hhq input file  
clear all
set more off
set maxvar 10000
*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}
*Bringing in nhhm variable from hhm data
use "${gsdData}/0-RawTemp/hhm_anon.dta", clear
collapse nhhm, by (state ea hh)
merge 1:1 state ea hh using "${gsdData}/0-RawTemp/hhq_anon.dta", assert(match) keep(match) nogen
*Rename variables by adding relevant prefixes
*Shortening one variable name
ren resolving_community_conflict resolve_comm_conflict
*Tag non-sn items
local nonsn "state ea enum weight treat hh hh_id nhhm res_age res_work res_active sws"
ds `nonsn', not
*Save variable names and variable labels
foreach var of varlist `r(varlist)' {
	*Store variable labels
	local oldlabel : variable label `var'
	*Obtain questionnaire item numbers from variable labels
	local space = strpos(`"`oldlabel'"', " ")
	local sn = substr(`"`oldlabel'"', 1, `space'-1)
	*Remove period from item numbers
	local sn = subinstr(`"`sn'"',".","_",4)
	*Rename variables their respective item numbers
	rename `var' `sn'_`var'
} 
*Reorder based on alphabetic-numeric order
order *, sequential
*Recode variables 
assert missing(A_14_migr_dec13_cause) if A_13_migr_dec13 != 1
recode A_14_migr_dec13_cause (.=.z) if A_13_migr_dec13 != 1
foreach var of varlist BF* {
	recode `var' (.=.z) if missing(BF_1_fempl_nat)
}
foreach var of varlist BF_1_fempl_wage BG_3_gjob_wage BR_0_hhm_empl_cwage BR_2_1_hhm_ewage BR_2_2_hhm_mwage BR_2_4_hhm_rwage{
	replace `var' = -98 if `var'_dk == 1
	replace `var' = -99 if `var'_dk == 99
	replace `var'_curr = 0 if `var'_dk == 1 | `var'_dk == 99
	*As there are no observations for specification of other currency
	assert missing(`var'_curr_sp)
	drop `var'_dk `var'_curr_sp
}
foreach var of varlist BF_5_fempl_miss_d BR_0_1_hhm_empl_cwage_d BR_0_2_hhm_empl_cwage_h C_4_hhh_migra_number{
	replace `var' = -98 if `var'_dk == 1
	replace `var' = -99 if `var'_dk == 99
	drop `var'_dk
}
recode BG_1_gjob_yn (.=.z) if missing(BG_1_gjob_yn)
recode BG* (.=.z) if (BG_1_gjob_yn!=1)
replace BG_2_gjob_time_m = -98 if BG_2_gjob_time_dk == 1
replace BG_2_gjob_time_y = -98 if BG_2_gjob_time_dk == 1
drop BG_2_gjob_time_dk
recode C_2_1_hhh_birthplace_ssd (.=.z) if C_2_hhh_birthplace != 1
recode C_2_2_countyborn (.=.z) if C_2_hhh_birthplace != 1
*Dropping unnecessary variables
drop C_3_hhh_migration_y C_3_hhh_migration_m C_3_hhh_migration_dk
recode C_4* (.=.z) if C_3_hhh_migra_time <12
recode C_5_1_hhh_migra_from_state (.=.z) if  (C_5_hhh_migra_from!=3)
recode C_5_2_hhh_migra_from_county (.=.z) if C_5_hhh_migra_from != 2
recode C_5_1_hhh_migra_from_region (.=.z) if C_5_1_hhh_migra_from_region !=4
recode C_6_hhh_push_factor (.=.z) if C_3_hhh_migra_time > 60 & !missing(C_3_hhh_migra_time)
recode C_7_hhh_pull_factor (.=.z) if C_3_hhh_migra_time > 60 & !missing(C_3_hhh_migra_time)
*There are no missing values for number of rooms and number of rooms used for sleeping
drop D_2_rooms_dk D_3_slrooms_dk
*Household characteristics
*Recode variables on water access
recode D_5_1_drink_source (.=.z) if D_5_water_home == 1  
recode D_6_water_time_sum (.=.z) if D_5_water_home == 1
replace D_6_water_time_sum = -98 if D_6_water_time_dk == 1
drop D_6_water_time_dk
recode D_12* (.=.z) if D_11_land_own != 1
recode D_13* (.=.z) if D_11_land_own != 1
recode D_13_1_land_own_gen (.=.z) if D_13_land_own_dur_n == 5
recode D_14* (.=.z) if D_11_land_own != 1
foreach list in D_16_tmarket D_17_tedu D_18_thealth {
	replace `list'_sum = -98 if `list'_dk == 1
	replace `list'_sum = -99 if `list'_dk == 99
	drop `list'_dk
}
*Recode variables on hunger
recode D_19_1_hunger_coping (.=.z) if D_19_hunger >1
*Questions about why the repondents will not go to police to resolve dispute
recode G_P_4_1* (.=.z) if G_P_4_dispute_resolve ==5 | G_P_4_dispute_resolve == -98| G_P_4_dispute_resolve == -99
*Recode variables Physical, Psychological, and Social Wellbeing 
recode L_2_move_to_country (.=.z) if L_1_move_want != 2
recode L_2_1_move_to_state (.=.z) if L_2_move_to_country  !=1
recode L_2_2_move_to_county (.=.z) if (L_2_move_to_country !=1)
foreach v of varlist L_3_move_why L_4_move_return L_5_move_help1 L_5_move_help2 L_5_move_help3  L_2_1_move_to_state L_2_2_move_to_county L_4_1_move_return_other1 L_4_1_move_return_other2 L_4_1_move_return_other3 L_4_1_move_return_other4 L_4_1_move_return_other5   L_3_1_move_why_multi1 L_3_1_move_why_multi2 L_3_1_move_why_multi3 L_3_1_move_why_multi4  {
	recode `v' (.=.z) if L_1_move_want > 2
}
*Questions about impact of IDPs' presence 
foreach v of varlist LI_2_idp_job_c LI_2_1_idp_job LI_2_pos_neg{
	recode `v' (.=.z) if LI_1_idp_presence != 0 
}
*Questions about coping strategies
foreach v of varlist J_6_cop_lesspreferred J_7_cop_limitportion J_8_cop_limitadult J_9_cop_reducemeals J_10_cop_borrowrely J_11_cop_skip J_12_cop_collect J_13_cop_soldmore J_14_cop_eatelsewhere J_15_cop_spentsav J_16_cop_seeds J_17_cop_borrow J_18_cop_sellassets J_19_cop_reduceexp J_20_cop_migrate J_21_cop_beg J_22_cop_sellfemales J_23_cop_contsell J_24_cop_sellmonths {
	recode `v' (.=.z) if J_5_nomoney == 0
}
recode J_23_cop_contsell (. = .z) if J_13_cop_soldmore != 1
recode J_24_cop_sellmonths (.=.z) if  J_23_cop_contsell != 1
recode K_2_neighborh_problems (.=.z) if K_1_neighborh_diff == -98 | K_1_neighborh_diff == -99
recode K_11_violence_n (.=.z) if K_10_violence != 1
foreach v of varlist L_3* L_4* L_5*{
	capture recode `v' (.=.z) if L_1_move_want !=1 & L_1_move_want!=2
}
foreach v of varlist M_1* M_2* M_3* M_4* M_5*  {
	capture recode `v' (.=.z) if M_0_harm_12m1 == 0 
}
*Recode dk and refusals as missing for selected variables; 
*Categorise missing values: "Don't know": -98 --> .a "Refused to respond": -99 --> .b
*ssc install labmv
labmv, mv(-99 .b  -98 .a -97 .z) all
qui label dir
foreach label in `r(names)' {
	label define `label' .a "Don't know" .b "Refused to respond" .z "Not Applicable", modify
}
*add value labels to non-valuelabelled variables
ds state ea weight hh enum nhhm A_2_2_hhsid_replace C_3_hhh* C_4_hhh* D_2_rooms_n D_3_slrooms_n D_6_water_time_sum D_16_tmarket_sum D_17_tedu_sum D_18_thealth_sum treat D_7_light D_20_lhood D_21_lhood_prev L_2_2_move_to_county L_3_move_why Z_8_* , not
foreach var in `r(varlist)' {
	local vlab : value label `var'
	if "`vlab'"==""  {
		label define l`var' .a "Don't know" .b "Refused to respond"  .z "Not Applicable", modify
		capture label val `var' l`var'
	}
	else {
	display "do nothing"
	} 
}	
*Create a variable for duration of interviews:
gen duration=A_1_end_time-A_1_start_time
replace duration=round(duration/(60*60*1000))
*Drop variables that contain private information
drop A_2_3_hhsid_org Z_2_1_respondent_name hh_id
*Drop redundant variables: 
drop A_1_today_auto A_1_today_manu  A_2_hhsid A_4_hhlid_check 
order state ea hh enum  
*Assign appropriate labels to variables 
label var ea "Enumeration Area"
label var hh "Household ID"
label var enum "Enumerator ID"
label var duration "Duration of interview (hrs)"
label var LI_3_more_less "The presence of IDPs has made your neighbrh more/less safe"
label var D_6_water_time_sum "D.6. Time Spent on Getting Water"
label var D_8_cook "D.8. Source of Cooking"
label var D_9_toilet "D.9. Toilet Facility"
label var D_15_phone_network "D.15. Phone Network"
label var D_19_hunger "D.19 No Food in Past Month"
label var D_5_1_drink_source "D.5.1. Drinking Water Source"
*Generate variable that specifies to which module households were assigned
gen mod_hh = treat 
tab treat
label var mod_hh "Household module assignment"
label var treat "Household module assignment"
*Recode date variable 
gen month = mofd(dofC(A_1_submissiondate))
format %tm month
*9 interviews with missing month, replace with median
quietly su month, detail
replace month=r(p50) if missing(month)
label var month "Month of Interview"
drop A_1_submissiondate 
*Drop unnecessary variables 
drop A_1_start_time A_1_end_time Enumerator_team_name res_active res_age res_work sws _isvalidated _group_hh_id _min_rownonmiss _tag1 _tag2 _tag3 treat Please* I_99_qr_resp_id A_2_2_hhsid_replace
*Rectify order of variables according to questionnaire
rename nhhm hhsize
order state ea weight hh enum mod_hh duration month hhsize 
save "${gsdData}/1-CleanInput/hhq.dta", replace
