* This do file prepares sharable version of hhm input file 
clear all
set more off
set maxvar 10000
*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}
*Load anonymized hhm data 
use "${gsdData}/0-RawTemp/hhm_anon.dta", clear
ren hhm_* *
ren rhhm_* *
drop nhhm
*Remaining recodes
*first fix some missing variables
replace empl_primary12m = -99 if empl_primary12m == 9
replace empl_primary7d = -99 if empl_primary7d == 9
*Recode dk and refusals as missing for selected variables; 
*Categorise missing values: "Don't know": -98 --> .a "Refused to respond": -99 --> .b
*ssc install labmv
labmv, mv(-99 .b  -98 .a) all
qui label dir
foreach label in `r(names)' {
	label define `label' .a "Don't know" .b "Refused to respond" .z "Not Applicable", modify
}
*add value labels to non-valuelabelled variables
ds state ea hh age empl_act12* empl_dk12* hhmid, not
foreach var in `r(varlist)' {
	local vlab : value label `var'
	if "`vlab'"==""  {
		label define l`var' .a "Don't know" .b "Refused to respond" .z"Not Applicable" , modify
		capture label val `var' l`var'
	}
	else {
	display "do nothing"
	}
}
* Relabel skip patterns based on relevance conditions in Questionnaire
* Skip pattern consistency and missing values due to skip patterns . ==> .z
*Relation to household head if ishead == 0 
assert relation==. if ishead==1 
recode relation (.=.z) if ishead==1
recode edu_level (.=.z) if edu_current == 1 | edu_ever == 1
recode edu_ever (.=.z) if edu_current == 0
*Occupation related variables occ*
ds occ*, not(type string)
foreach v of varlist `r(varlist)' {
	recode `v' (.=.z) if age<10 
}
recode occ_clerq (.=.z) if occ_lev1 != 4 
recode occ_craft (.=.z) if occ_lev1 != 7
recode occ_elem (.=.z) if occ_lev1 != 9
recode occ_forces (.=.z) if occ_lev1 != 10
recode occ_mgr (.=.z) if occ_lev1 != 1
recode occ_plant (.=.z) if occ_lev1 != 8
recode occ_prof (.=.z) if occ_lev1 != 2
recode occ_service (.=.z) if occ_lev1 != 5
recode occ_skilled (.=.z) if occ_lev1 != 6
recode occ_tech(.=.z) if occ_lev1 != 3
*Employment related variables
foreach v of varlist empl_appr12m empl_farm12m empl_inc12m empl_bus12m empl_fhelp12m {
	recode `v' (.=.z) if age<10 
}	
recode empl_primary12m `v' (.=.z) if empl_act12m < 1 
*Apprenticeship related variables
foreach v of varlist empl_appr12m empl_appr_ever empl_farm_ever empl_inc_ever empl_bus_ever empl_fhelp_ever {
	recode `v' (.=.z) if empl_act12m==0
}	
*Activity in past 7 days 
recode empl_active7d  (.=.z) if empl_act_ever ==0 & empl_dk_ever == 0 
recode empl7d_temp (.=.z) if empl_active7d != 0 & empl_dk_ever !=0 *empl_act_ever != 0 
recode empl_primary7d (.=.z) if empl_active7d == 0
recode empl_primary7d_kind (.=.z) if empl_active7d == 0
recode empl7d_inactive (.=.z) if empl_active7d == 1
recode empl7d_temp (.=.z) if empl_active7d == 1
recode empl_status (.=.z) if empl_active7d == 0 
*Job search 
recode job_search (.=.z) if age <10 | age_dk == 1
recode job_search_type (.=.z) if age <10 | age_dk == 1
recode job_search_no (.=.z) if job_search == 1
*Drop unnecessary variables
drop pos emp_12m_a emp_12m_b emp_12m_f emp_12m_h emp_12m_reminder empl_act_ever empl_dk_ever emp_12m_p
*Rename variables by adding relevant prefixes 
*Tag non-sn items
local nonsn "state ea hh hhmid"
ds `nonsn', not
*Save variable names and variable labels
foreach var of varlist `r(varlist)' {
	*Store variable labels
	local oldlabel : variable label `var'
	*Obtain questionnaire item numbers from variable labels
	local space = strpos(`"`oldlabel'"', " ")
	local sn = substr(`"`oldlabel'"', 1, `space'-1)
	*Remove period from item numbers
	local sn = subinstr(`"`sn'"',".","_",4)
	*Rename variables their respective item numbers
	rename `var' `sn'_`var'
} 
*Further check skip patterns
ds BE*, not (type string)
foreach var of varlist `r(varlist)' {
	recode `var' (.=.z) if BB_4_age <=5
}
ds BE_5* BW*, not (type string)
foreach var of varlist `r(varlist)' {
	recode `var' (.=.z) if BB_4_age < 10
}
*Migration variables migr* if ishead == 0 
ds BM*, not (type string)
foreach var of varlist `r(varlist)' {
	recode `var' (.=.z) if B_3_ishead == 1
}
foreach var of varlist BM_2* BM_3 {
	recode `var' (.=.z) if BM_1_migr_never != 0
}
*Reorder based on alphabetic-numeric order
order *, sequential
order state ea hh hhmid
label var ea "Enumeration Area"
label var hh "Household ID"
*Sort and save 
sort state ea hh hhmid
save "${gsdData}/1-CleanInput/hhm.dta", replace
