* This do file prepares sharable version of assets input file 
clear all
set more off
set maxvar 10000
*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}
*Prepare dataset that contains constraints for assets
clear 
insheet using "${gsdDataRaw}\General\section_h_wave2.csv", clear
label var c_min_h "Minimum hard constraint"
label var c_max_h "Maximum hard constraint"
save "${gsdData}\0-RawTemp\assets_constraints.dta", replace
*place exchange rate data in the 1-cleaninput/other folder
import delimited using "${gsdDataRaw}/General/exchange_rates.csv" , clear
*adjust SDD exchange rate to be expressed in SSP
replace conv2ssp = conv2ssp/100 if year<2007
replace conv2usd=conv2usd/100 if year<2007 & curr=="SSP"
save "${gsdData}/1-CleanInput/Other/exchange_rates.dta" , replace 
*create median wave 1 depreciation rates
use "${gsdDataRaw}/Wave1/1-CleanOutput/assets.dta" , clear  
collapse (median) drate_w1=drate , by(index)
save "${gsdData}/1-CleanInput/Other/drate_w1.dta" , replace

*Load anonymized hhq data 
use "${gsdData}/0-RawTemp/assets_anon.dta", clear
set more off
*Soft and hard constraints for non-food items
rename ra_* *
merge m:1 index using "${gsdData}\0-RawTemp\assets_constraints.dta", nogen keepusing(c_min_h c_max_h) assert(match master) keep(match master)
*Add labels
label var ea "Enumeration Area (anonymised)"
label var hh "Household ID (anonymised)"
*Checking skip patterns
ds state ea hh index own xmas xxmas c_min_h c_max_h, not
foreach var of varlist `r(varlist)' {
assert missing(`var') if own != 1
}
*Set current asset holdings to 0 if HH does not own the asset
replace owntotal = 0 if own == 0 & xown == 0
replace owntotal = -98 if xown == 1
replace owntotal = -99 if xown == 99
drop xown
assert !missing(ynew) if xynew == 0
replace ynew = -98 if xynew == 1
replace ynew = -99 if xynew == 99
drop xynew
assert !missing(prnew) if xprnew == 0
assert missing(prnew) if xprnew != 0 
replace prnew = -98 if xprnew == 1
replace prnew = -99 if xprnew == 99
*There are currencies mentioned, even when no price is given.
*Replacing those entries to 0 - 'Not Applicable - Price unknown'.
replace cprnew = 0 if xprnew == 1 | xprnew == 99
*As no price was noted as zero
drop prnewzero xprnew
assert !missing(sellnew) if xsellnew == 0
assert missing(sellnew) if xsellnew != 0 
replace sellnew = -98 if xsellnew == 1
replace sellnew = -99 if xsellnew == 99
*Again there are entries for currencies without any entries for price
*Replacing those entries to 0 - 'Not Applicable - Price unknown'.
replace csellnew = 0 if xsellnew == 1 | xsellnew == 99
*As no sales price was quoted to be zero
drop sellnewzero xsellnew
assert !missing(sellall) if xsellall == 0
assert missing(sellall) if xsellall != 0 
replace sellall = -98 if xsellall == 1
replace sellall = -99 if xsellall == 99
*Again there are entries for currencies without any entries for price
*Replacing those entries to 0 - 'Not Applicable - Price unknown'.
replace csellall = 0 if xsellall == 1 | xsellall == 99
*As no sales price was quoted to be zero
drop sellallzero xsellall
assert !missing(xmas) if xxmas == 0
assert missing(xmas) if xxmas != 0 
replace xmas = -98 if xxmas == 1
replace xmas = -99 if xxmas == 99
drop xxmas
*Recode dk and refusals as missing for selected variables; 
*Categorise missing values: "Don't know": -98 --> .a "Refused to respond": -99 --> .b
*ssc install labmv
labmv, mv(-99 .b  -98 .a) all
ds, not (type string)
foreach v of varlist `r(varlist)' {
	recode `v' (.=.z)
}
qui label dir
foreach label in `r(names)' {
	label define `label' .a "Don't know" .b "Refused to respond" .z "Not Applicable", modify
}
*add value labels to non-valuelabelled variables
ds state ea hh c_*, not
foreach var in `r(varlist)' {
	local vlab : value label `var'
	if "`vlab'"==""  {
		label define l`var' .a "Don't know" .b "Refused to respond" .z "Not Applicable" , modify
		capture label val `var' l`var'
	}
	else {
	display "do nothing"
	}
}
* xcsellall is missing all observations
drop xcsellall
*Rename variables
rename ( ynew xmas ) ( year_purc owntotal_preconflict )
rename (prnew cprnew xcprnew ) ( price_purc curr_purc currother_purc )
rename (sellnew csellnew xcsellnew ) (price_sell curr_sell currother_sell)
rename csellall curr_sellall
*Generate pre-conflict ownership indicator
gen own_preconflict = .
replace own_preconflict = 0 if owntotal_preconflict == 0 & !missing(owntotal_preconflict)
replace own_preconflict = 1 if owntotal_preconflict > 0 & !missing(owntotal_preconflict)
label values own_preconflict ra_own
label var own_pre "Did the household own any of \${ra_namelp} before the conflict?"
*clean up and save
order state ea hh index 
order own_preconflict ,before(owntotal_preconflict)
sort state ea hh index 
save "${gsdData}/1-CleanInput/assets.dta", replace
