* This do file prepares sharable version of livestock input file 
*Prepare dataset that has constraints for livestock items
clear all
set more off
set maxvar 10000

*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}
insheet using "${gsdDataRaw}\General\section_g_wave2.csv"
label var c_max_s "Maximum soft constraint"
label var c_max_h "Maximum hard constraint"
save "${gsdData}\0-RawTemp\livestock_constraints.dta", replace
*Load anonymized livestock data
use "${gsdData}/0-RawTemp/livestock_anon.dta", clear
set more off
*Rename variables
rename rl_* *
*Merge soft and hard constraints for non-food items
merge m:1 index using "${gsdData}\0-RawTemp\livestock_constraints.dta", nogen keepusing(c_max_s c_max_h) 
*Check skip patterns
ds state ea hh index raise c_max_s c_max_h, not
foreach var of varlist `r(varlist)' {
assert missing(`var') if raise != 1
}
foreach v of varlist heads born price cprice sellkill given rgiven bought lost lost {
	recode `v' (.=.z) if raise==0 | raise==.a | raise==.b
}
replace cprice = 0 if xprice == 1 | xprice == 99
foreach var of varlist heads born price sellkill given bought lost {
	assert !missing(`var') if x`var' == 0
	assert missing(`var') if x`var' == 1 | x`var' == 99
	replace `var' = -98 if x`var' == 1
	replace `var' = -99 if x`var' == 99
	drop x`var'
}
*Recode dk and refusals as missing for selected variables; 
*Categorise missing values: "Don't know": -98 --> .a "Refused to respond": -99 --> .b
*ssc install labmv
labmv, mv(-99 .b  -98 .a) all
ds raise, not
foreach v of varlist `r(varlist)' {
	recode `v' (.=.z)
}
qui label dir
foreach label in `r(names)' {
	label define `label' .a "Don't know" .b "Refused to respond" .z "Not Applicable", modify
}
*add value labels to non-valuelabelled variables
ds state ea hh c_max*, not
foreach var in `r(varlist)' {
	local vlab : value label `var'
	if "`vlab'"==""  {
		label define l`var' .a "Don't know" .b "Refused to respond" .z "Not Applicable" , modify
		capture label val `var' l`var'
	}
	else {
	display "do nothing"
	}
}
*Add labels
label var ea "Enumeration Area"
label var hh "Household ID"
*label var mod_hh "Module assignment"
* Remove empty rows for livestock that was not raised, born, owned or given away
*Check that we do not delete any relevant information
tabstat heads born price cprice sellkill given rgiven bought lost if raise !=1 
********************************************************************************
* Reorder, sort and save as clean input file
********************************************************************************
sort state ea hh index 
order state ea hh index raise
save "${gsdData}/1-CleanInput/livestock.dta", replace
