* This do file prepares sharable version of food input file 
clear all
set more off
set maxvar 10000
*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}
*Place median foodprices from wave 1 in 1-CleanInput to later calculate the deflator
import delimited using "${gsdDataRaw}/General/foodprices_medians_W1.csv" , clear
keep if urban=="Urban" & tm=="2015m7"
drop urban tm 
rename uprice ref
save "${gsdData}/1-CleanTemp/foodprices_medians_W1.dta" , replace
*create file with constraints
insheet using "${gsdDataRaw}\General\section_e_wave2.csv" , clear
encode u1, gen(unit)
save "${gsdData}\0-RawTemp\food_constraints.dta", replace
*prepare food data
use "${gsdData}/0-RawTemp/food_anon.dta", clear
*create item recall variable
gen item_recall=7 if !missing(relevanceyn) 
*encode item_name variable
rename item_name item_name_
encode item_name_, gen(item_name)
drop item_name_
*replace don't know and refused to respond in relevanceyn
replace relevanceyn = . if relevanceyn == 98 | relevanceyn == 99
*Check skip patterns
ds state ea hh itemid item_category item_name item_module relevanceyn *min *max item_recall, not
foreach var of varlist `r(varlist)' {
	assert missing(`var') if relevanceyn == 0 
}
assert !missing(cons_quant) if cons_unit_options == 0
assert missing(cons_quant) if cons_unit_options == 1 | cons_unit_options == 98
replace cons_quant = -98 if cons_unit_options == 1
replace cons_quant = -99 if cons_unit_options == 98
replace cons_unit = 0 if cons_unit_options == 1  | cons_unit_options == 98
label define lfoodunit 0 "Not Applicable (Quantity not known)", add
drop cons_unit_options
assert !missing(purc_quant) if purc_unit_options == 0
assert missing(purc_quant) if purc_unit_options == 1 | purc_unit_options == 98
replace purc_quant = -98 if purc_unit_options == 1
replace purc_quant = -99 if purc_unit_options == 98
replace purc_unit = 0 if purc_unit_options == 1 | purc_unit_options == 98 
drop purc_unit_options
assert !missing(pric_total) if pric_options == 0
assert missing(pric_total) if pric_options == 1 | pric_options == 98
replace pric_total = -98 if pric_options == 1
replace pric_total = -99 if pric_options == 98
replace pric_curr = 0 if pric_options == 1 | pric_options == 98 
label define epric_curr 0 "Not Applicable (Price not known)", add
drop pric_options
replace free_yn = -98 if free_yn == 98
replace free_yn = -99 if free_yn == 99
foreach var of varlist *low *high {
	assert `var' == 1 if !missing(`var')
}
drop *low *high
*Renaming to be consistent with Wave1:
rename (item_module relevanceyn cons_quant cons_unit cons_min cons_max purc_quant purc_unit purc_min purc_max pric_min pric_max pric_total pric_curr cons_conv2kg purc_conv2kg) 		(mod_item cons cons_q cons_u c_min_s c_max_s purc_q purc_u p_min_s p_max_s pr_min_s pr_max_s price curr conv2kg_cons conv2kg_purc)
*merge constraints and conversionf factors; first for cons. and then for purc. (conversion factors that are in the survey are wrong, therefore the quantities automatically calculated in kg must be dropped too)
drop conv2kg_* cons_quant_kg purc_quant_kg
rename cons_u unit
merge m:1 itemid unit using "${gsdData}\0-RawTemp\food_constraints.dta" , assert(match master) keep(match master) keepusing(conv2kg c_min_h c_max_h) nogen
rename unit cons_u
rename conv2kg conv2kg_cons
rename purc_u unit
merge m:1 itemid unit using "${gsdData}\0-RawTemp\food_constraints.dta" , assert(match master) keep(match master) keepusing(conv2kg p_min_h p_max_h) nogen
rename unit purc_u
rename conv2kg conv2kg_purc
*the conversion factor for millilitres is missingfrom the pull form, so manually replace it
replace conv2kg_cons=0.001 if cons_u==13
replace conv2kg_purc=0.001 if purc_u==13
*Recode dk and refusals as missing for selected variables; 
*Categorise missing values: "Don't know": -98 --> .a "Refused to respond": -99 --> .b
*Skip pattern consistency and missing values due to skip patterns . ==> .z
ds, not(type string)
foreach var of varlist `r(varlist)' {
	recode `var' (.=.z)
}
qui label dir
*Categorise missing values: "Don't know": -98 or 98 --> .a "Refused to respond": -99 or 99 --> .b
*ssc install labmv
labmv, mv(-99 .b  -98 .a) all
qui label dir
*add value labels to the missing values
foreach label in `r(names)' {
	label define `label' .a "Don't know" .b "Refused to respond" .z "Not Applicable", modify
}
*add value labels to non-valuelabelled variables
ds state ea hh itemid mod_item pr_m* conv2kg_* *_s item_recall , not
foreach var in `r(varlist)' {
	local vlab : value label `var'
	if "`vlab'"==""  {
		label define l`var' .a "Don't know" .b "Refused to respond" .z "Not Applicable" , modify
		capture label val `var' l`var'
	}
	else {
	display "do nothing"
	}
}
*label variables
label var ea "Enumeration Area"
label var hh "Household ID"
label var cons "Over the past 7 days, did anyone in your household consume or obtain any {product}?"
label var cons_q "What was the total quantity consumed by the household in the last 7 days?"
label var purc_q "What was the total quantity purchased by the household in the last 7 days?"
label var free_yn "Did your household receive any of the consumed {product} for free (instead of purchasing it) over the past 7 days?"
label var free_main "Where did you receive most of the free {product} from?"
label var free_other "If other, please specify where most of the free {product} came from."
label var conv2kg_cons "Conversion_2_kg factor for unit consumed"
label var conv2kg_purc "Conversion_2_kg factor for unit purchased"
label var c_min_s "Soft constraint for quantity consumed"
label var c_max_s "Soft constraint for quantity consumed"
label var p_max_s "Soft constraint for quantity purchased"
label var p_min_s "Soft constraint for quantity purchased"
label var c_min_h "Hard constraint for quantity consumed"
label var c_max_h "Hard constraint for quantity consumed"
label var p_min_h "Hard constraint for quantity purchased"
label var p_max_h "Hard constraint for quantity purchased"
label var pr_max_s "Soft constraint for price"
label var pr_min_s "Soft constraint for price"
label var mod_item "Optional module of the consumed item"
label var item_recall "Recall period, days"
*drop redundant vars
drop cons_convert pric_curr_label purc_convert pric_zero pric_ssp pric_sspperkg keep_community_clean 
*drop if missing(cons) | cons==0
rename (item_category item_name ) (catlabel itemlabel) 
*reorder
order state ea hh catlabel itemlabel itemid cons cons_* purc_* 
order c_min_s c_min_h c_max_s c_max_h conv2kg_cons p_min_s p_min_h p_max_s p_max_h conv2kg_purc pr_min_s pr_max_s , last
sort state ea hh itemid
save "${gsdData}/1-CleanInput/food.dta" , replace
*create a file containing food item labels for future reference
use "${gsdData}/1-CleanInput/food.dta" , clear
collapse itemid , by(itemlabel catlabel mod_item)
save "${gsdData}/1-CleanTemp/food_items.dta" , replace

*prepare wave 1 median and average prices for calculation of the deflator:
use "${gsdDataRaw}/Wave1/Temp/food-share.dta", clear
drop if urban==0
*use national median if missing
bysort itemid: egen uprice_med_all = median(uprice)
collapse (median) uprice_med = uprice  [pweight=weight], by(tm itemid uprice_med_all)
replace uprice_med = uprice_med_all if missing(uprice_med)
drop uprice_med_all
keep if tm == ym(2015,7)
rename uprice_med uprice_med_w1
save "${gsdTemp}/food-prices_W1.dta", replace


