* This do file prepares sharable version of non-food input file 
* Prepare datasets with constraints for non-food items
clear all
set more off
set maxvar 10000

*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}
*create file with constraints
insheet using "${gsdDataRaw}\General\section_f_wave2.csv" , clear
rename v10 c_max_s
save "${gsdData}\0-RawTemp\nonfood_constraints.dta", replace
*prepare nonfood data
use "${gsdData}/0-RawTemp/nonfood_anon.dta", clear
encode item_name, gen(itemlabel)
drop item_name 
tab item_module, mis
rename item_category catlabel
*Calculate mean number of items consumed for core and non-core items
replace relevanceyn = . if relevanceyn == 98 | relevanceyn == 99
bysort state ea hh : egen sum_total = sum(relevanceyn) 
egen mean_total = mean(sum_total) if item_module == 0 | item_module == 1 | item_module ==  2 | item_module ==  3 | item_module == 4
bysort state ea hh: egen sum_core = sum(relevanceyn)  if item_module == 0 
egen mean_core = mean(sum_core)
bysort state ea hh: egen sum_opt = sum(relevanceyn)  if item_module == 1 | item_module ==  2 | item_module ==  3 | item_module == 4 
egen mean_opt = mean(sum_opt) 
* Adding Soft and hard constraints for non-food items
merge m:1 itemid using "${gsdData}\0-RawTemp\nonfood_constraints.dta", nogen keepusing(recall c_min_h c_min_s c_max_s	c_max_h) assert(match master) keep(match master)
* Add label to variables
label var c_min_h "Minimum hard constraint"
label var c_min_s "Minimum soft constraint"
label var c_max_h "Maximum hard constraint"
label var c_max_s "Maximum soft constraint"
label var itemid "Item ID"
label var ea "Enumeration Area"
label var hh "Household ID"
label var recall "Recall period"
label var item_module "Optional module of the consumed item"
label var itemlabel "Item label"
label var catlabel "Item category"
*Recode skip patterns
recode pric_total (.=.z) if relevanceyn==0 | relevanceyn==.a | relevanceyn==.b
recode pric_curr (.=.z) if relevanceyn==0 | relevanceyn==.a | relevanceyn==.b
*Checking skip patterns
assert !missing(pric_total) if pric_options == 0
assert missing(pric_total) if pric_options == 1
replace pric_curr = 0 if pric_options == 1
label define fpric_curr 0 "Not applicable (Price unknown)", add
drop pric_options
assert missing(free_yn) if relevanceyn == 0
replace free_yn = -98 if free_yn == 98
replace free_yn = -99 if free_yn == 99
assert missing(free_main) if free_yn != 1
*Cleaning variables
assert pric_sspperkg_low == 1 if !missing(pric_sspperkg_low)
assert pric_sspperkg_high == 1 if !missing(pric_sspperkg_high)
drop pric_sspperkg*
*Recode Not applicables 
ds, not(type string)
foreach var of varlist `r(varlist)' {
	recode `var' (.=.z)
}
*Categorise missing values: "Don't know": -98 or 98 --> .a "Refused to respond": -99 or 99 --> .b
*ssc install labmv
labmv, mv(-99 .b  -98 .a) all
qui label dir
foreach label in `r(names)' {
	label define `label' .a "Don't know" .b "Refused to respond" .z "Not Applicable", modify
}
*define variables that do not require labelling of missing values
ds state ea hh itemid c_* pric_min pric_max item_module recall , not
foreach var in `r(varlist)' {
	local vlab : value label `var'
	if "`vlab'"==""  {
		label define l`var' .a "Don't know" .b "Refused to respond" .z "Not Applicable" , modify
		capture label val `var' l`var'
	}
	else {
	display "do nothing"
	}
}
*Reorder and save as clean input file
*rename 
rename (relevanceyn pric_total pric_curr item_module  )(cons price curr mod_item )
order state ea hh catlabel itemlabel itemid cons price curr item_recall c_min_h c_min_s c_max_s c_max_h 
assert item_recall == recall
drop item_recall sum_total mean_total sum_core mean_core sum_opt mean_opt
save "${gsdData}/1-CleanInput/nonfood.dta", replace
*create a file containing food item labels for future reference
use "${gsdData}/1-CleanInput/nonfood.dta" , clear
collapse itemid , by(itemlabel catlabel mod_item)
save "${gsdData}/1-CleanTemp/nonfood_items.dta" , replace
