*This file 
	*	Aggregates non missing values for each household.
	*	Identify duplicate observations.
	*	Clean and consolidate variables	
use "${gsdData}/0-RawTemp/hhq_preEAcheck.dta", clear
order ea
label variable ea "EA"
ren key parent_key	
*Compute non-missing values for all modules of raw data
*Save data prior to generating non-missing values
save "${gsdTemp}/pregen_nonmissing.dta", replace
*Generate count of non-missing values for each observation (including missing values of string variables) and save non-missing count
egen rownonmiss_hhq = rownonmiss(*), strok
keep rownonmiss_hhq parent_key
save "${gsdData}/0-RawTemp/nonmissing_hhq.dta", replace
*Next generate count of non-missing values across all other sets of raw data
foreach sf in hhm livestock assets food nonfood {
	*Load data
	use "${gsdDataRaw}/`sf'.dta", clear
	*Generate number of non-missing values
	egen rownonmiss_`sf' = rownonmiss(*), strok
	*Collapse to household level
	collapse (sum) rownonmiss_`sf', by(parent_key)
	save "${gsdData}/0-RawTemp/nonmissing_`sf'.dta", replace
}
*Merge non-missing values from all other sets of raw data
use "${gsdTemp}/pregen_nonmissing.dta", clear
merge m:1 parent_key using "${gsdData}/0-RawTemp/nonmissing_hhq.dta", keep(match master) nogenerate
merge m:1 parent_key using "${gsdData}/0-RawTemp/nonmissing_hhm.dta", keep(match master) nogenerate
merge m:1 parent_key using "${gsdData}/0-RawTemp/nonmissing_livestock.dta", keep(match master) nogenerate
merge m:1 parent_key using "${gsdData}/0-RawTemp/nonmissing_assets.dta", keep(match master) nogenerate
*Aggregate non-missing values for each household
gen rownonmiss = rownonmiss_hhq + rownonmiss_hhm + rownonmiss_livestock + rownonmiss_assets
*Drop empty rows in hhq data
drop if rownonmiss_hhq == 0
*Cleaning Name Variables - Removing leading and trailing blanks and changing all alphabets to upper case.
foreach var of varlist enum_name enum_identity team_name hhm_name* hhr_name hhh_name* {
	replace `var' = strtrim(`var')
	replace `var' = upper(`var')
}
*Ensuring that all interviews are valid:
*Ensure that all observations are fieldwork and drop variables confirming it.
assert missing(confirmexam) & missing(confirmtraining) & confirmfieldwork == 1 
drop confirm* examnumber type
*Drop observations if no one is at home
drop if athome == 0
assert adult == consent == maycontinue == 1
drop athome adult consent maycontinue
*Consolidating Variables
*consolidate unique ID into "key" variable
replace parent_key=instanceid if missing(parent_key)
drop instanceid
*Drop nhhm - the variable is wrongly calculated.
drop nhhm
*Drop intermediary variables used to calculate hhh_name and hhr_name
assert hhh_name == hhh_name0 if hhh_presence > 0 & !missing(hhh_presence)
replace hhh_name = hhh_name0 if hhh_presence == 0 & missing(hhh_name)
assert !missing(hhh_name)
drop hhr_id hhh_id0 hhh_name0 hhh_presence hhh_id1 hhh_options hhh_id
*Investigate range of respondent ages
tab res_age
*Tabulate distribution of respondent ages for respondents who are less than or equal to 18 years of age
tab res_age if res_age <= 18
tabout res_age if res_age <= 18 using "${gsdOutput}/tab_age.txt", cells(freq) format(0c) clab(Freq.) replace
*Look at records with respondents who are less than or equal to 18 years of age
sort res_age
list hhr_name res_age parent_key if res_age <= 18
list hhr_name res_age parent_key if res_age <= 18 & hhr_name != ""
*Set age to missing for respondents who are recorded as 17 years old or younger
replace res_age = . if res_age < 18
*Consolidating and verifying hh_id's
*hh_id's are household listing id's and should be unique to each household in an enumeration area.
duplicates tag ea hh_id, gen(tag)
sort ea hh_id hhh_name 
list ea hh_id hhh_name enum_identity return visit_n success_interview rownonmiss start_time end_time roster if tag == 1
*There are 36 duplicate hh_id's in the dataset.
*There are wrong entries of hh_id's in the dataset. Checked manually with listing_hhidsW1W2.dta
replace hh_id = "D28" if parent_key == "uuid:ff965a2a-9f8a-4a36-9c04-414a178d45e4"
replace hh_id = "A10" if parent_key == "uuid:921451d8-43bf-46c3-9e20-74c7fe4de5ff"
replace hh_id = "A8" if parent_key == "uuid:ce51261f-7e15-421c-b5f3-b8fc6cba9983"
replace hh_id = "C2" if parent_key == "uuid:fab4c2a6-2e30-452c-b7b3-2e15eee1071e"
replace hh_id = "C7" if parent_key == "uuid:3c902e5a-7fe0-4e1c-8cc5-366b088b5e57"
replace hh_id = "A10" if parent_key == "uuid:b16fcd25-f8ca-49d1-9400-63a1a6dbefc6"
replace hh_id = "A18" if parent_key == "uuid:ce288ae6-273b-4812-87f0-85fe5e4dc98e"
replace hh_id = "B19" if parent_key == "uuid:3f497386-fcfe-4d94-a7d8-29c7f2036dc5"
replace hh_id = "B24" if parent_key == "uuid:eada4cbc-1baf-4e88-8db4-24dddf2d2ba5"
replace hh_id = "B23" if parent_key == "uuid:3ad40f8f-f3b0-4cd3-88f4-a40ff25e3ad6"
replace hh_id = "C2" if parent_key == "uuid:1b952176-9c41-48f7-8d82-36d734404cfb"
replace hh_id = "C12" if parent_key == "uuid:ce35d6b9-aa7f-4fe2-8915-b53cc5b36b8e"
replace hh_id = "C17" if parent_key == "uuid:ff964060-af1c-47e8-81b4-e3c7714aaf76"
replace hh_id = "C27" if parent_key == "uuid:f2d02ef8-8741-4421-a23e-f96b1bd79e7a"
replace hh_id = "C20" if parent_key == "uuid:bbe76660-d661-4919-bf01-09be5fede4b9"
replace hh_id = "B16" if parent_key == "uuid:374cba4a-cbe3-4d63-9376-593bb2b6374e"
replace hh_id = "C12" if parent_key == "uuid:cbd871a0-c5d8-4e66-bdc6-7e41ce227423"
replace hh_id = "C18" if parent_key == "uuid:d59b2f27-5de6-441c-9094-658b77a94841"
*Here the household head name did not match. But the name in the roster matched the household head name as provided in the listing.
replace hh_id = "D5" if parent_key == "uuid:ff01c232-96f1-4c00-9322-0770650b931c"
replace hh_id = "C9" if parent_key == "uuid:438ec0e9-f7bd-4457-84c8-9ad9958c2881"
*There are some duplicate hh_id's that are not solved by looking at the listingW1W2.dta
*There are still three pairs of duplicates left
duplicates tag ea hh_id, gen(tag1)
egen group_hh_id = group(hh_id) if tag1 == 1
list ea hh_id hhh_name enum_identity return visit_n success_interview rownonmiss start_time end_time roster group_hh_id if !missing(group_hh_id)
*There are duplicate entries for the same household, hhh_name = DENG  LUAL MAJAK. The enumerator seemed to have interviewed the same household twice.
*We keep the observation that has the most complete data.
bysort group_hh_id: egen min_rownonmiss = min(rownonmiss) 
drop if rownonmiss == min_rownonmiss & ea == 810306001107 & hh_id == "C9"
*I am unable to ascertain the true hh_id's of the remaining two pairs as these names and these hh_id's do not appear in the listing form.
*I keep their hh_id's as it is. 
drop tag*
*There are other wrong entries in hh_id in Wave2 as compared with hh_id's in Listing form and hh_id's in Wave1.
*Cleaning hh_id's:
*Manually checking the household roster and changing hh_id's to correspond to hh_id's as in the listing form or as in the Wave1 data.
replace hh_id = "D24" if parent_key == "uuid:a9280d0a-010a-46a5-b6dc-7abfe686cba6"
replace hh_id = "A8" if parent_key == "uuid:8f715dae-f06e-4ac9-86d6-6db51bccf527"
replace hh_id = "C16" if parent_key == "uuid:33ff4f0d-aed3-424d-9f9b-77911c473ec8"
replace hh_id = "A4" if parent_key == "uuid:29e448ca-b028-40e5-b239-7d3232f45085"
replace hh_id = "D3" if parent_key == "uuid:9d3f2873-d5ce-481d-b187-088cad6457f1"
replace hh_id = "C16" if parent_key == "uuid:39cf9620-63b4-4e55-9df0-173cd67448d1"
*The below hhh_name was not found in listing-hhidsW1W2.dta, and the hh_id is replaced with the hh_id in Wave1.
replace hh_id = "B101" if parent_key == "uuid:0eb86dc1-124e-45d3-b438-4d5323a1eda8"
replace hh_id = "B21" if parent_key == "uuid:a614c362-abf6-445e-baf8-9882efd63157"
*The below hhh_name was not found in listing-hhidsW1W2.dta, and the hh_id is replaced with the hh_id in Wave1.
replace hh_id = "B66" if parent_key == "uuid:8b70456c-26c0-4ccd-93d2-6cff3f202357"
replace hh_id = "B20" if parent_key == "uuid:881b158d-882b-44ac-b3eb-76e5a78b2ec1"
replace hh_id = "B9" if parent_key == "uuid:dbd0d039-8547-483d-b020-20d05b24a590"
replace hh_id = "B2" if parent_key == "uuid:dd920d25-e9a2-4a5d-b47c-40254114644b"
replace hh_id = "B17" if parent_key == "uuid:a58afc66-89f0-47ad-9fb2-0aef2ffae4f8"
replace hh_id = "C17" if parent_key == "uuid:96dfc017-5ed9-4ae5-9598-3231fba093ef"
replace hh_id = "B6" if parent_key == "uuid:f69457e6-f3be-416f-8bc2-f03038b4d2f7"
replace hh_id = "B1" if parent_key == "uuid:06643259-4bb7-4106-858d-138e7756e624"
replace hh_id = "C7" if parent_key == "uuid:faafe07a-955c-4956-a0f9-6fa581720f15"
replace hh_id = "C25" if parent_key == "uuid:f69456c6-f6f5-48ee-84ce-e9f1225441e2"
replace hh_id = "A30" if parent_key == "uuid:14556009-8cd9-485b-9067-3a06476bb7c3"
replace hh_id = "A5" if parent_key == "uuid:9ed7cff8-303c-48dc-b626-cbd71249768f"
replace hh_id = "A19" if parent_key == "uuid:db2cca1b-c8e2-4b10-a148-40f0f147032e"
*The hhh_name below was not found in listing-hhidsW1W2.dta, and the hh_id is replaced with the hh_id in Wave1.
replace hh_id = "B65" if parent_key == "uuid:e0c79597-3a49-44a0-87fc-f46dd8695d60"
*The hhh_name below was not found in listing-hhidsW1W2.dta, and the hh_id is replaced with the hh_id in Wave1.
replace hh_id = "D92" if parent_key == "uuid:8b44da9b-b6ec-4fae-8bb9-4837e98ebce4"
*Consolidating variables identifying geolocation
list loclatitude latx if loclatitude != latx
replace loclatitude = latx if missing(loclatitude)
list loclongitude longx if loclongitude != longx
replace loclongitude = longx if missing(loclongitude)
list locaccuracy accx if locaccuracy != accx
replace locaccuracy = accx if missing(locaccuracy)
drop latx longx accx loc_check*
*Consolidating enumerator identifying variables
gen str20 enum_clean=""
replace enum_clean = substr(enum_identity, 1, strpos(enum_identity, " FROM")-1)
replace enum_clean = substr(enum_identity, 1, strpos(enum_identity, ",")-1) if enum_clean==""
replace enum_clean = enum_identity if missing(enum_clean)
save "${gsdTemp}/hhq_pre_enumclean.dta", replace
*Importing correct Enumerator names for observations where enumerator names are missing.
*Manual replacements where people scanned the wrong barcode; Simon BK Timon was sharing his tablet, but this seems correct based on start_time
import delimited "${gsdDataRaw}/General/enum_clean.csv", bindquote(strict) clear
format enum_name %12.0g
tostring enum_name, replace format(%12.0f)
merge 1:m enum_name using "${gsdTemp}/hhq_pre_enumclean.dta", keep(master using match) nogen 
ren enum_clean enum_m
_crcslbl enum_m enum_identity
*Dropping intermediary variables
drop qr_id qr_idcheck team_id enum_id enum_name enum_check enum_identity
*Create consolidated household revisit variables 
* The questionnaires have either the variables return_yn or return_yn2, with the same labels.
* The same variable was named differently in two versions of the form. And the code below is consolidating so that we have one variable for each.(Andrew confirmed this.)
tostring qr_return_id2, replace force
replace qr_return_id2="830304012105" if parent_key=="uuid:b9cae3ff-99ba-4cac-994b-1f71b7ab3b9b" 
replace qr_return_id2="" if qr_return_id2=="."
foreach x in return_yn qr_yn qr_confirm qr_hhh_yn hhh_v  {
	gen `x'3=.
	assert `x'==. | `x'2==. 
	replace `x'3=`x' if `x'3==.
	replace `x'3=`x'2 if `x'3==.
	order `x'3, after(`x')
}
foreach x in qr_hhh hhh_other qr_return_id  {
	gen str20 `x'3=""
	assert `x'=="" | `x'2==""
	replace `x'3=`x' if `x'3==""
	replace `x'3=`x'2 if `x'3==""
	order `x'3, after(`x')
}
foreach x in return_yn qr_yn qr_confirm qr_hhh_yn hhh_v qr_hhh hhh_other qr_return_id  {
	_crcslbl `x'3 `x'
	drop `x' `x'2
	ren `x'3 `x'
}
*There are wrong entries in qr_hhh_yn. qr_hhh_yn should be yes when qr_hhh == hhh_name
replace qr_hhh_yn = 0 if qr_hhh == "Name not in list"
replace qr_hhh_yn = 1 if qr_hhh == hhh_name & !missing(hhh_name)
*Consolidating qr_return_id and qr_resp_id:
replace qr_resp_id = qr_return_id if missing(qr_resp_id)
*There are three cases of conflict between qr_return_id and qr_resp_id
list qr_resp_id qr_return_id if qr_resp_id != qr_return_id & !missing(qr_return_id)
*Resolving conflict:
*Checking with Wave1 data shows that there is no qr_resp_id of "910765". 
*This value is therefore replaced with the corresponding qr_return_id of "910727" which correctly matches with the household in Wave1.
replace qr_resp_id = "910727" if qr_resp_id == "910765"
*For the other two conflicts, the qr_return_id of "910990" and "910989" does not appear in Wave1 data.
*Basic tests for data quality and coherence
*tabulation of basic stats
di "Is this a household that you or your team interviewed before?"
tab return_yn,m
di "Do they still have the QR code that your team gave them?"
tab  qr_yn return_yn,m
di "Please scan this QR code that you gave them before"
tab qr_return_id qr_yn,m
drop qr_return_id qr_yn return_yn qr_confirm qr_hhh hhh_v 
*Cleaning of Variables
*Cleaning of QR_RESP_ID
*qr_resp_id variable has errors with some values of length 8, 12, 16 and 52 digits. 
*There were three QRcodes to be scanned: One for Enumeration Area, One for enumerator, One for household.
*The errors were due to enumerators scanning wrong QRcodes. There was one 8-digit value in qr_resp_id in Warrap State. 
*Warrap State was not visited in Wave1 so I do not know what this 8 digit Id could be.
*For Eastern Equatoria, 16 digit barcodes were printed.
gen qr_resp_clean = qr_resp_id if length(qr_resp_id) == 6
replace qr_resp_clean = substr(qr_resp_id,11,6) if length(qr_resp_id) == 16
duplicates tag qr_resp_clean if !missing(qr_resp_clean), generate(tag1)
tab tag1, mi
bysort qr_resp_clean: gen nqr = _N
sort qr_resp_id today_auto start_time
drop tag1
save "${gsdTemp}/predrop.dta", replace
*There are duplicate entries for qr_resp_clean. None of the duplicate entries of qr_resp_id except for 930001 appear in Wave1. 
*930001 is the barcode that had been printed repeatedly by mistake and given to households in Eastern Equatoria.
*Check: 
keep if nqr != 1 & qr_resp_clean != "930001" & qr_resp_clean != ""
keep qr_resp_clean
ren qr_resp_clean qr_resp_id
duplicates drop
merge 1:m qr_resp_id using "${gsdDataRaw}/Wave1/0-RawOutput/hhq.dta", gen(match)
assert match != 3
*Remove all the duplicate entries of qr_resp_id
use "${gsdTemp}\predrop.dta", clear
replace qr_resp_clean = "" if nqr > 1
_crcslbl qr_resp_clean qr_resp_id
drop qr_resp_id nqr
ren qr_resp_clean qr_resp_id
*Split and destring various string variables - 
foreach var of varlist hhh_religion move_why_multi move_return_other move_help harm_12m harm_help_spec respondent_q_section {
	*Obtain old label
	local oldlabel : variable label `var'
	*Split string variable
	split `var', parse(" ")
	forvalues i = 1/`r(nvars)' {
		*Destring split string variables
		quietly destring `var'`i', replace
		*Apply old label to split variables
		label var `var'`i' "`oldlabel'"
	}
	*Drop original string variable
	drop `var'
}
label define hhh_religion 1 "Christianity" 2 "Islam" 3 "Traditional African Religion" 4 "Judaism" 5 "Buddhism" 6 "Hinduism" 7 "Agnostic" 8 "Atheism" 1000 "Other (Specify)" -98 "Don't know" -99 "Refused to respond"
label values hhh_religion1 hhh_religion
label values hhh_religion2 hhh_religion
label define move_why_multi 1 "Belongings stolen" 2 "Absence of authority" 3 "Do not feel safe" 4 "No financial means to return" 5 "House damaged/destroyed" 6 "Work tools stolen" 7 "I want to wait for the political situation to develop/stabilize" 8 "I want to receive humanitarian aid" 9 "I participate in economic activities here" 10 "I don't have income anymore when I return" 11 "I have better access to education here" 12 "I have better access to health here" 13 "Other (Specify)" -98 "Don't knpw" -99 "Refused to respond"
label values move_why_multi* move_why_multi
label values move_return_other* move_return
label define move_help 0 "None" 1 "Security" 2 "Housing" 3 "Non-food items" 4 "Employment" 5 "Food" 6 "Furniture" 7 "Access to health services" 8 "Phychosocial support" 9 "Training" 10 "Education" 11 "Access to water" 12 "Transport" -98 "Don't know" -99 "Refused to respond"
label values move_help* move_help
label values harm_12m* harm_one
label define harm_help_spec 1 "Medical care" 2 "Psychosocial care/counselling" 3 "Moral support" 4 "Community support" 5 "Counseling from religious/tribal leaders" 6 "Financial support" 7 "Preventive information" 8 "Legal support"
label values harm_help_spec1 harm_help_spec
label values harm_help_spec2 harm_help_spec
label values harm_help_spec3 harm_help_spec
label values harm_help_spec4 harm_help_spec
label values harm_help_spec5 harm_help_spec
label values harm_help_spec6 harm_help_spec
*Identify potential duplicates
*Tag potential duplicate #1: records with identical GPS coordinates
duplicates tag loclatitude loclongitude localtitude if loclatitude != . & loclongitude != . & localtitude != . , generate(tag1)
replace tag1 = 0 if tag1 == .
*Tag potential duplicate #2: records with identical respondent names
duplicates tag hhr_name, generate(tag2)
*Tag potential duplicate #3: records with identical household head names
duplicates tag hhh_name, generate(tag3)
*Generate group indicators within each duplicate type
*Tag groups within duplicate type #1
egen duplicategroup_hhq_1 = group(loclatitude loclongitude localtitude) if tag1 == 1
*Tag groups within duplicate type #2
egen duplicategroup_hhq_2 = group(hhr_name) if tag2 == 1 
*Tag groups within duplicate type #3
egen duplicategroup_hhq_3 = group(hhh_name) if tag3 == 1
*Compute distance between groups within duplicate types #2 and #3
*Compute distance between groups of potential duplicates in categories #2 and #3
do "${gsdDo}/fDistance.do"
foreach num of numlist 2 3 {
	sort duplicategroup_hhq_`num', stable
	bysort duplicategroup_hhq_`num': gen loclatitude_a = loclatitude[_n+1] if duplicategroup_hhq_`num' != .
	bysort duplicategroup_hhq_`num': gen loclongitude_a = loclongitude[_n+1] if duplicategroup_hhq_`num' != .
	quietly fDistance loclatitude loclongitude loclatitude_a loclongitude_a dist_`num' if duplicategroup_hhq_`num' != .
	drop loclatitude_a loclongitude_a
}
*Generate master distance variable for potential duplicates #2 and #3
gen dist = dist_2 if duplicategroup_hhq_2 != .
replace dist = dist_3 if duplicategroup_hhq_3 != .
drop dist_2 dist_3
*Generate a variable identifying how many household member names are exactly repeated across the duplicate observations.
sort duplicategroup_hhq*
gen hhm_n = 0
forvalues i = 1/30 {
	forvalues j = 1/30 {
	replace hhm_n = hhm_n+1 if hhm_name_`i' == hhm_name_`j'[_n+1] & hhm_name_`i'!=""
	}
}
*Manually inspect potential duplicate records
*Manually inspect potential duplicates #1 - There are no duplicates #1
sort tag1 duplicategroup_hhq_1
list hhh_name enum_m today_auto today_manu start_time end_time if tag1 == 1
*Manually inspect potential duplicates #2
sort duplicategroup_hhq_2 today_auto
list duplicategroup_hhq_2 hhh_name dist hhm_n ea enum_m today_auto today_manu start_time end_time roster return visit_n success_interview rownonmiss parent_key hh_id if tag2 == 1
*Manual inspection shows that the observations for which duplicategroup_hhq_2 = 3 and for which duplicategroup_hhq_2 = 6 appear to be duplicate on the basis of geographic location and names, ages and genders of household members.
bysort duplicategroup_hhq_2: egen min = min(rownonmiss) if duplicategroup_hhq_2 == 3 | duplicategroup_hhq_2 == 6
drop if rownonmiss == min & (duplicategroup_hhq_2 == 3 | duplicategroup_hhq_2 == 6)
drop min
*Manually inspect potential duplicate #3
sort duplicategroup_hhq_3 today_auto
list duplicategroup_hhq_3 hhr_name dist hhm_n ea enum_m today_auto today_manu start_time end_time roster if tag3 == 1
*Manual inspection shows that there are three households with duplicate hhh_name. All these interviews are conducted by one enumerator.
*This same enumerator had been spotted to have done fake interviews. I listened to the audio and two different persons are speaking in the audio. SO, I will keep the observations.
*Generate other duplicate indicators and save all duplicate-related information
*Further drop unnecessary variables
drop *audio* rownonmiss* dist duplicate* set* dur_mod* hhlid_1 hhlid_2* *gg* rep_* roster validnames* linebreak modules hhm_all hhm_count hhm_name* tedu_d tedu_h tedu_m thealth_d thealth_h thealth_m tmarket_d tmarket_h tmarket_m water_time_d water_time_h water_time_m hhm_n formdef_version fcs_count return visit_n
order ea state loc*, after(submissiondate)
*Fix order
*Tag non-sn items
local nonsn "state ea parent_key enum_m treat hh_id hhr_name hhh_name res_age res_work res_active sws"
ds `nonsn', not
*Save variable names and variable labels
foreach var of varlist `r(varlist)' {
	*Store variable labels
	local oldlabel : variable label `var'
	*Obtain questionnaire item numbers from variable labels
	local space = strpos(`"`oldlabel'"', " ")
	local sn = substr(`"`oldlabel'"', 1, `space' - 1)
	*Remove period from item numbers
	local sn = subinstr(`"`sn'"',".","",4)
	*Rename variables their respective item numbers
	rename `var' `sn'`var'
}
*Reorder based on alphabetic-numeric order
order *, sequential
*Tag non-sn items
ds `nonsn', not
*Restore original variable names
foreach var of varlist `r(varlist)' {
	*Store variable labels
	local oldlabel : variable label `var'
	*Obtain questionnaire item numbers from variable labels
	local space = strpos(`"`oldlabel'"', " ")
	local sn = substr(`"`oldlabel'"', 1, `space' - 1)
	*Remove period from item numbers	
	local sn = subinstr(`"`sn'"',".","",4)
	*Create new variable names that do not include the item numbers incorporated earlier
	local newvar = subinstr("`var'","`sn'","",1)
	*Rename variables their earlier variable names
	rename `var' `newvar'
}
*Place key non-sn items at front of variable list
order state ea parent_key enum_m start_time end_time submissiondate today_auto today_manu, first
