	do init
*this do file creates output for use with excel to create a monitoring dashboard

*Latest changes
* 26 June (azadel): Clean up code and elaboarate comments.

**********************************
* ZERO -- SETUP
**********************************

*0.1 folder configuration
if "${l_sdData}"=="" {
	di as error "Configure work environment by running init.do before running the code."
	error 1
}
set more off

*0.2 create dta file for list of EAs in sample
import excel "${l_sdData}\0-RawInput\panel_1_sample_compiled.xlsx", clear first
rename smpl_EA ea
format ea %12.0f
save "${l_sdData}\0-RawOutput\pane1_1_sample_compiled", replace


**********************************
* ONE -- GENERATE RAW FOOD SCORES
**********************************

*1.1 Use raw data from the food consumption module and calculate how many items were consumed from each module.
use "${l_sdData}/0-RawOutput/raw food.dta", clear

*Eliminate don't know and refused to respond answers.
replace erelevanceyn=. if erelevanceyn!=1

*Calculate number of items consumed for each module and collapse these counts by interview using parent_key.
forvalues i = 0/4 {
	gen mod`i'_cons=.
	replace mod`i'_cons=1 if eitem_module==`i' & erelevanceyn==1
}
forvalues i = 0/4 {
	gen econs_quant_nonmiss`i'=.
	replace econs_quant_nonmiss`i'=1 if eitem_module==`i' & erelevanceyn==1 & econs_quant!=.
}
collapse (sum) erelevanceyn econs_quant_nonmiss? mod* ,by(parent_key)

*1.2 Calculate percentages of food items consumed for each module.

*Caluculate percentage of items consumed out of total items on each list.
gen pct_cons_allfood=erelevanceyn/140
gen pct_cons_mod0=mod0_cons/33
gen pct_cons_mod1=mod1_cons/27
gen pct_cons_mod2=mod2_cons/26
gen pct_cons_mod3=mod3_cons/26
gen pct_cons_mod4=mod4_cons/28
egen pct_cons_optional=rowmax(pct_cons_mod1 pct_cons_mod2 pct_cons_mod3 pct_cons_mod4)
gen pct_econs_quant_nonmiss=(econs_quant_nonmiss0+econs_quant_nonmiss1+econs_quant_nonmiss2+econs_quant_nonmiss3+econs_quant_nonmiss4)/erelevanceyn
forvalues i = 0/4 {
	gen pct_nonmiss_mod`i'=econs_quant_nonmiss`i'/mod`i'_cons
}
*pct_nonmiss_optional refers to whatever optional module (treat) was used for that interview.
egen pct_nonmiss_optional=rowmax(pct_nonmiss_mod1 pct_nonmiss_mod2 pct_nonmiss_mod3 pct_nonmiss_mod4)

*Save the food percentage scores for each interview. To be merged back in later.
save "${l_sdData}\0-RawOutput\food_collapse", replace


**********************************
* TWO -- CLEAN HH DATA
**********************************

*2.1 Prepare HHQ data to be used for the dashboard.

*Load formatted hhq data - no variables have been dropped
use "${l_sdData}/0-RawOutput/0-2-hhq-cons.dta", clear

*Clean enumerator identity
gen str20 enum_clean=""
replace enum_clean = substr(enum_identity, 1, strpos(enum_identity, " from")-1)
replace enum_clean = substr(enum_identity, 1, strpos(enum_identity, ",")-1) if enum_clean==""
replace enum_clean = enum_identity if enum_clean==""

*order deviceid enum_clea enum_identity
*sort deviceid

*Manual replacements where people scanned the wrong barcode; Simon BK Timon was sharing his tablet, but this seems correct based on start_time
replace enum_clean="Gordon Ludu Paulo" if parent_key=="uuid:b7f0a55d-82e5-4587-b868-cd03ab22f0e2"
replace enum_clean="Kenyi Samuel Tunagi" if parent_key=="uuid:f1b64ef5-84bf-4a16-9149-2e11ae3cd7c0"
replace enum_clean="Abraham Ayii Deng" if parent_key=="uuid:fbd17d0f-c610-4fb9-91c6-151dd88f0700"
replace enum_clean="Simon BK Timon" if parent_key=="uuid:96dfc017-5ed9-4ae5-9598-3231fba093ef"
replace enum_clean="Simon BK Timon" if parent_key=="uuid:a50f8000-de7b-406b-8669-02e1cf53a843"

ren ea_clean ea


*2.2 Check that all EAs are in the sample and create insample flag
merge m:1 ea using "${l_sdData}\0-RawOutput\pane1_1_sample_compiled", keep(match master)
gen insample=1
replace insample=0 if _merge!=3
replace insample=0 if s_v==82 & replacement==1

ren ea ea_clean
order ea_clean
drop _merge


**********************************
* THREE -- FORMAT HH DATA
**********************************

*3.1 Format state and time data

*Add state labels
label define ls_v 71 "Malakal" 72 "JNG" 81 "WRP" 82 "NBG" 83 "WBG" 84 "LKS" 91 "WES" 92 "CES" 93 "EES"
label values s_v ls_v

*Calculate interview time and drop any interviews longer than 5 hours long.
gen interview_duration=end_time-start_time
replace interview_duration=round(interview_duration/(60*1000))
order interview_duration
replace interview_duration=. if interview_duration>300

*Create flags for each treatment
forvalues i = 1/4 {
	gen int treat`i'= treat==`i'
	la var treat`i' "Treat`i'"
}

*Create manual labels for each month to facilitate the graphing in Excel
gen interview_count=1
gen date_dif=today_auto-today_manu
gen str3 today_auto_month=""
replace today_auto_month="Jan" if month(today_auto)==1
replace today_auto_month="Feb" if month(today_auto)==2
replace today_auto_month="Mar" if month(today_auto)==3
replace today_auto_month="Apr" if month(today_auto)==4
replace today_auto_month="May" if month(today_auto)==5


*3.2 Generate EA and interview indicators

*Count how many EAs and valid EAs
bys ea_clean: egen new_ea=seq()
replace new_ea=. if new_ea!=1
gen new_ea_valid=.
replace new_ea_valid=1 if new_ea==1 & insample==1
replace new_ea_valid=0 if new_ea==1 & insample==0

*Count replacement EAs
gen new_replac_ea=.
replace new_replac_ea=1 if new_ea==1 & replacement==1

*Count how many interviews not started
gen not_start=.
replace not_start=1 if consent !=1

*Count how many interviews are replacement interviews
gen hhsid_replace_count=.
replace hhsid_replace_count=1 if hhsid==-1000

save "${l_sdData}/0-RawOutput/hhq_formatted.dta", replace


*3.3 Generate table with merged food score data; save for later use
use "${l_sdData}\0-RawOutput\hhq_formatted", clear
merge 1:1 parent_key using "${l_sdData}\0-RawOutput\food_collapse", keep(match) nogen
save "${l_sdData}/0-RawOutput/hhq_foodscores.dta", replace


*3.4 Generate basic table summarizing all interviews for dashboard; save for later use

use "${l_sdData}/0-RawOutput/hhq_formatted.dta", clear

local goodvars "ea_clean new_ea new_ea_valid interview_count s_v replacement insample enum_clean today_auto today_manu date_dif start_time end_time interview_duration submissiondate hhsid hhsid_replace hhsid_org treat treat1 treat2 treat3 treat4 hhlid_1 hhlid_2 hh_id loclatitude loclongitude localtitude locaccuracy athome adult maycontinue consent deviceid key today_auto_month"
keep `goodvars'
order `goodvars'

sort ea hhsid_org

la var ea_clean "EA"
la var s_v "State"
la var smpl_EA_name "EA Name (state, county, payam, boma, EA)"
la var replacement "Replacement"
la var insample "Insample"
la var enum_clean "Enumerator"
la var today_auto "Beginning of Interview - Auto"
la var today_manu "Beginning of Interview - Manual"
la var date_dif "Date difference between beginning of interviews"
la var start_time "Start time"
la var end_time "End time"
la var interview_duration "Interview duration in minutes"
la var submissiondate "Date form sent to server"
la var hhsid "HH interview number (-1000 is replacement)"
la var hhsid_replace "HH interview number for replacements"
la var treat "Treatment Number"
la var treat1 "Treatment = 1"
la var treat2 "Treatment = 2"
la var treat3 "Treatment = 3"
la var treat4 "Treatment = 4"
la var hhlid_1 "HH ID from listing"
la var hhlid_2 "HH ID from listing"
la var hh_id "HH ID from listing"
la var loclatitude "GPS Latitude"
la var loclongitude "GPS Longitude"
la var localtitude "GPS Altitude"
la var locaccuracy "GPS Accuracy"
la var athome "Someone at home"
la var adult "Adult present"
la var maycontinue "Ask to continue interview"
la var consent "Consent given"
la var return_yn "return_yn"
la var qr_yn "qr_yn"
la var qr_return_id "qr_return_id"
la var qr_confirm "qr_confirm"
la var qr_hhh "qr_hhh"
la var qr_hhh_yn "qr_hhh_yn"
la var hhh_v "hhh_v"
la var hhh_other "hhh_other"
la var deviceid "Tablet ID"
la var parent_key "unique key"
la var today_auto_month "Month of Collection Interview"

*state labels
label values s_v ls_v

*Save formatted data for later use
save "${l_sdData}\0-RawOutput\panel_dashboard_formatted", replace

*Export raw dashboard data to "Interviews - Output" tab
export excel using "${l_sdData}\0-RawOutput\Panel_Dashboard.xlsx", sheetreplace sheet("Interviews - Output") first(varl) cell(A4)


******************************************************
* FOUR -- DASHBOARD OUTPUT: CUMULATIVE COUNTS
******************************************************

*4.1 Cumulative interview count for the whole project

*Use formated data and create balanced time series; generate cumulative counts
use "${l_sdData}\0-RawOutput\panel_dashboard_formatted", clear
gen today_auto_dow=dow(today_auto)
gen wBegin = today_auto-today_auto_dow
collapse (sum) interview_count, by(wBegin)
tsset wBegin, delta(7)
tsfill
gen interview_count_cumul=sum(interview_count)

*Label variables for output
la var wBegin "Week of data collection" 
la var interview_count "Nb of interviews completed"
la var interview_count_cumul "Nb of conducted interview - Cumulative"
format wBegin %td

*Export to dashboard excel file; modify only that tab
export excel using "${l_sdData}\0-RawOutput\Panel_Dashboard.xlsx", sheetmodify sheet("Graph 9 - Interv Whole Project") first(varl) cell(A4)


*4.2 cumulative indicators by enumerator

*Use formated data and collapse by enumerator
use "${l_sdData}\0-RawOutput\panel_dashboard_formatted", clear
order enum_clean today_auto interview_count
collapse (sum) interview_count, by(enum_clean today_auto)
sort enum_clean today_auto

*Convert enumerator identity into a number to allow for timeseries operations; generate cumulative counts
encode enum_clean, gen(enum_num)
drop enum_clean
order enum_num
tsset enum_num today_auto
tsfill, full
by enum_num: gen interview_count_cumul=sum(interview_count)

*Label variables for output
la var enum_num "Enumerator"
la var today_auto "Day of data collection" 
la var interview_count "Nb of interviews completed"
la var interview_count_cumul "Nb of conducted interview - Cumulative"

*Export to dashboard excel file; modify only that tab
export excel using "${l_sdData}\0-RawOutput\Panel_Dashboard.xlsx", sheetmodify sheet("Enumerator II - Output") first(varl) cell(A4)


*4.3 cumulative indicators by team

*Use formated data and collapse by state; create balanced time series and cumulative counts
use "${l_sdData}\0-RawOutput\panel_dashboard_formatted", clear
order s_v today_auto interview_count
collapse (sum) interview_count new_ea, by(s_v today_auto)
sort s_v today_auto
tsset s_v today_auto
tsfill, full
by s_v: gen interview_count_cumul=sum(interview_count)
by s_v: gen ea_count_cumul=sum(new_ea)

*Label variables for output
la var s_v "Team (state)"
la var today_auto "Day of data collection" 
la var interview_count "Nb of interviews completed"
la var interview_count_cumul "Nb of interviews completed - Cumulative"
la var new_ea "Nb of EAs completed"
la var ea_count_cumul "Nb of EAs completed - Cumulative"

*Export to dashboard excel file; modify only that tab
export excel using "${l_sdData}\0-RawOutput\Panel_Dashboard.xlsx", sheetmodify sheet("Team II - Output") first(varl) cell(A4)


******************************************************
* FIVE -- DASHBOARD OUTPUT: INDICATORS BY ENUMERATOR
******************************************************

*5.1 Indicators by enumerator

*Use interview table with merged food item scores
use "${l_sdData}/0-RawOutput/hhq_foodscores.dta", clear

*Create markers for each interview that is the first for a new EA
drop new_ea new_ea_valid
bys enum_clean ea_clean: egen new_ea=seq()
replace new_ea=. if new_ea!=1
gen new_ea_valid=.
replace new_ea_valid=1 if new_ea==1 & insample==1
replace new_ea_valid=0 if new_ea==1 & insample==0

*Collapse all relevant indicators by enumerator and sort by enumerator
collapse (sum) interview_count=interview_count interviews_not_started=not_start number_of_EAs=new_ea number_valid_EAs=new_ea_valid panel_revisit=return_yn treat1 treat2 treat3 treat4 hhsid_replace_count (min) s_v first_date=today_auto (p50) med_pct_food_QC_all=pct_econs_quant_nonmiss med_intv_time=interview_duration med_pct_food_all=pct_cons_allfood med_pct_food_core=pct_cons_mod0 med_pct_food_opt=pct_cons_optional med_pct_food_QC_core=pct_nonmiss_mod0 med_pct_food_QC_opt=pct_nonmiss_optional (mean) mean_pct_food_QC_all=pct_econs_quant_nonmiss mean_pct_food_all=pct_cons_allfood mean_pct_food_core=pct_cons_mod0 mean_pct_food_opt=pct_cons_optional mean_pct_food_QC_core=pct_nonmiss_mod0 mean_pct_food_QC_opt=pct_nonmiss_optional (mean) mean_intv_time=interview_duration (min) min_intv_time=interview_duration (max) max_intv_time=interview_duration, by(enum_clean)
format *int* %3.0f
sort enum_clean

*Generate percentage indicators based on collpased counts
gen pct_EAs_valid=number_valid_EAs/number_of_EAs
gen pct_treat1=treat1/interview_count
gen pct_treat2=treat2/interview_count
gen pct_treat3=treat3/interview_count
gen pct_treat4=treat4/interview_count
gen pct_HH_replacements=hhsid_replace_count/interview_count

*Label variables for output and add state labels
la var enum_clean "Enumerator Name"
la var s_v "Team (state)"
la var interview_count "Number of interviews completed (cumulative)"
la var interviews_not_started "Number of interviews not started"
la var number_of_EAs "Number of EAs visited"
la var number_valid_EAs "Number of valid EAs visited (insample and correct rep)"
la var panel_revisit "Number of interviews revisiting Wave1 respondent"
la var treat1 "Number of interviews with treatment 1"
la var treat2 "Number of interviews with treatment 2"
la var treat3 "Number of interviews with treatment 3"
la var treat4 "Number of interviews with treatment 4"
la var hhsid_replace_count "Number of replacement HH not in selected 12"
la var first_date "Earliest interview date"
la var med_intv_time "Median interview time in minutes"
la var med_pct_food_all "Median % food items consumed"
la var med_pct_food_core "Median % food items consumed from core module"
la var med_pct_food_opt "Median % food items consumed from optional module"
la var med_pct_food_QC_core "Median % quantities for consumed items, core module"
la var med_pct_food_QC_opt "Median % quantities for consumed items, optional module"
la var mean_pct_food_all "Mean % food items consumed"
la var mean_pct_food_core "Mean % food items consumed from core module"
la var mean_pct_food_opt "Mean % food items consumed from optional module"
la var mean_pct_food_QC_core "Mean % quantities for consumed items, core module"
la var mean_pct_food_QC_opt "Mean % quantities for consumed items, optional module"
la var mean_intv_time "Mean interview time in minutes"
la var min_intv_time "Minimum interview time in minutes"
la var max_intv_time "Maximum interview time in minutes"
la var pct_EAs_valid "% of EAs visited that were valid"
la var pct_treat1 "% interviews with treatment 1"
la var pct_treat2 "% interviews with treatment 2"
la var pct_treat3 "% interviews with treatment 3"
la var pct_treat4 "% interviews with treatment 4"
la var pct_HH_replacements "% of replacement HH not in selected 12"
la var med_pct_food_QC_all "Median % quantities for consumed items, all food items"
la values s_v ls_v

*Export to dashboard excel file; modify only that tab
order enum_clean s_v first_date interview_count interviews_not_started hhsid_replace_count pct_HH_replacements panel_revisit number_of_EAs number_valid_EAs pct_EAs_valid med_pct_food_all med_pct_food_core med_pct_food_opt med_pct_food_QC_all med_pct_food_QC_core med_pct_food_QC_opt mean_pct_food_all mean_pct_food_core mean_pct_food_opt mean_pct_food_QC_all mean_pct_food_QC_core mean_pct_food_QC_opt med_intv_time mean_intv_time min_intv_time max_intv_time treat1 treat2 treat3 treat4 pct_treat1 pct_treat2 pct_treat3 pct_treat4
export excel using "${l_sdData}\0-RawOutput\Panel_Dashboard.xlsx", sheetmodify sheet("Enumerator I - Output") first(varl) cell(A4)


******************************************************
* SIX -- DASHBOARD OUTPUT: INDICATORS BY TEAM
******************************************************

*6.1 Indicators by team

*Use interview table with merged food item scores
use "${l_sdData}/0-RawOutput/hhq_foodscores.dta", clear

*Collapse all relevant indicators by state (team) and sort by state
collapse (sum) interview_count=interview_count interviews_not_started=not_start number_of_EAs=new_ea number_valid_EAs=new_ea_valid number_ea_replac=new_replac_ea panel_revisit=return_yn treat1 treat2 treat3 treat4 hhsid_replace_count (min) first_date=today_auto (p50) med_pct_food_QC_all=pct_econs_quant_nonmiss med_intv_time=interview_duration med_pct_food_all=pct_cons_allfood med_pct_food_core=pct_cons_mod0 med_pct_food_opt=pct_cons_optional med_pct_food_QC_core=pct_nonmiss_mod0 med_pct_food_QC_opt=pct_nonmiss_optional (mean) mean_pct_food_QC_all=pct_econs_quant_nonmiss mean_pct_food_all=pct_cons_allfood mean_pct_food_core=pct_cons_mod0 mean_pct_food_opt=pct_cons_optional mean_pct_food_QC_core=pct_nonmiss_mod0 mean_pct_food_QC_opt=pct_nonmiss_optional (mean) mean_intv_time=interview_duration (min) min_intv_time=interview_duration (max) max_intv_time=interview_duration, by(s_v)
format *int* %3.0f
sort s_v

*Generate percentage indicators based on collpased counts
gen pct_EAs_valid=number_valid_EAs/number_of_EAs
gen pct_treat1=treat1/interview_count
gen pct_treat2=treat2/interview_count
gen pct_treat3=treat3/interview_count
gen pct_treat4=treat4/interview_count
gen pct_HH_replacements=hhsid_replace_count/interview_count

*Label variables for output and add state labels
la var s_v "State (team)"
la var interview_count "Number of interviews completed (cumulative)"
la var interviews_not_started "Number of interviews not started"
la var number_of_EAs "Number of EAs visited"
la var number_valid_EAs "Number of valid EAs visited (insample and correct rep)"
la var number_ea_replac "Number of replacement EAs visited (valid or invalid)"
la var panel_revisit "Number of interviews revisiting Wave1 respondent"
la var treat1 "Number of interviews with treatment 1"
la var treat2 "Number of interviews with treatment 2"
la var treat3 "Number of interviews with treatment 3"
la var treat4 "Number of interviews with treatment 4"
la var hhsid_replace_count "Number of replacement HH not in selected 12"
la var first_date "Earliest interview date"
la var med_intv_time "Median interview time in minutes"
la var med_pct_food_all "Median % food items consumed"
la var med_pct_food_core "Median % food items consumed from core module"
la var med_pct_food_opt "Median % food items consumed from optional module"
la var med_pct_food_QC_core "Median % quantities for consumed items, core module"
la var med_pct_food_QC_opt "Median % quantities for consumed items, optional module"
la var mean_intv_time "Mean interview time in minutes"
la var min_intv_time "Minimum interview time in minutes"
la var max_intv_time "Maximum interview time in minutes"
la var pct_EAs_valid "% of EAs visited that were valid"
la var pct_treat1 "% interviews with treatment 1"
la var pct_treat2 "% interviews with treatment 2"
la var pct_treat3 "% interviews with treatment 3"
la var pct_treat4 "% interviews with treatment 4"
la var pct_HH_replacements "% of replacement HH not in selected 12"
la var med_pct_food_QC_all "Median % quantities for consumed items, all food items"

*Export to dashboard excel file; modify only that tab
order s_v first_date interview_count interviews_not_started hhsid_replace_count pct_HH_replacements panel_revisit number_of_EAs number_valid_EAs pct_EAs_valid number_ea_replac med_pct_food_all med_pct_food_core med_pct_food_opt med_pct_food_QC_all med_pct_food_QC_core med_pct_food_QC_opt med_intv_time mean_pct_food_QC_all mean_pct_food_all mean_pct_food_core mean_pct_food_opt mean_pct_food_QC_core mean_pct_food_QC_opt mean_intv_time min_intv_time max_intv_time treat1 treat2 treat3 treat4 pct_treat1 pct_treat2 pct_treat3 pct_treat4
export excel using "${l_sdData}\0-RawOutput\Panel_Dashboard.xlsx", sheetmodify sheet("Team I - Output") first(varl) cell(A4)


******************************************************
* SEVEN -- SPECIFIC TESTS FOR ENUMERATOR PERFORMANCE AND DATA INTEGRITY
******************************************************

*7.1 Tests for enumerator performance
use "${l_sdData}/0-RawOutput/hhq_foodscores.dta", clear

gen dur_dif_a=(dur_mod_a-dur_mod_0)/60
gen dur_dif_b=(dur_mod_b-dur_mod_a)/60
gen dur_dif_c=(dur_mod_c-dur_mod_b)/60
gen dur_dif_d=(dur_mod_d-dur_mod_c)/60
gen dur_dif_e=(dur_mod_e-dur_mod_d)/60
gen dur_dif_f=(dur_mod_f-dur_mod_e)/60
gen dur_dif_g=(dur_mod_g-dur_mod_f)/60
gen dur_dif_h=(dur_mod_h-dur_mod_g)/60
gen dur_dif_i=(dur_mod_i-dur_mod_h)/60
gen dur_dif_j=(dur_mod_j-dur_mod_i)/60
gen dur_dif_k=(dur_mod_k-dur_mod_j)/60

ren (pct_nonmiss_mod0 pct_nonmiss_optional) (pct_quant_nonmiss_mod0 pct_quant_nonmiss_optional)

* calculate interview time and drop outliers
drop interview_duration
gen interview_duration=end_time-start_time
replace interview_duration=round(interview_duration/(60*1000))
order interview_duration
order dur_dif*
format dur_dif* %4.1f

*clean outliers
replace interview_duration=. if interview_duration>300
replace dur_dif_e=. if dur_dif_e<0

order today_auto s_v enum_clean interview_duration dur_dif_e erelevanceyn pct_econs_quant_nonmiss pct_quant_nonmiss_mod0 pct_quant_nonmiss_optional validnames_total loc*
sort enum_clean today_auto

collapse (first) s_v (p50)interview_duration (mean)dur_dif_e erelevanceyn pct_econs_quant_nonmiss pct_quant_nonmiss_mod0 pct_quant_nonmiss_optional validnames_total, by(enum_clean)

foreach x in interview_duration dur_dif_e erelevanceyn pct_econs_quant_nonmiss pct_quant_nonmiss_mod0 pct_quant_nonmiss_optional validnames_total {
	preserve
	keep s_v enum_clean `x'
	sort `x'
	order s_v
	export excel "${l_sdData}/0-RawOutput/enumerator_check", sheetreplace sheet("`x'")
	restore
}

*7.2 Basic tests for data quality and coherence

use "${l_sdData}/0-RawOutput/hhq_formatted.dta", clear

*tabulation of basic stats
di "Is this a household that you or your team interviewed before?"
tab return_yn,m
di "Do they still have the QR code that your team gave them?"
tab  qr_yn return_yn,m
di "Please scan this QR code that you gave them before"
tab qr_return_id qr_yn,m
	 
*look at consumption data
clear all
set maxvar 10000
import delim "${l_sdData}\0-Downloads\South Sudan HFS Panel Questionnaire-mod_e-rep_e.csv", clear
keep if erelevanceyn==0 | erelevanceyn==1
collapse (first) eitem_name (sum) erelevanceyn (count) econs_quant, by(eitemid)
sort erelevanceyn
gen econs_quant_pct= econs_quant/erelevanceyn
format econs_quant_pct %3.2f
*biggest is salt and sugar. hello USA
*78% have quantities
la var econs_quant_pct "Percentage of items consumed with a non-missing cons quantity."
la var econs_quant "Number of non-missing cons quantities for item in entire dataset"
la var erelevanceyn "Number of times item was consumed in entire dataset"
save "${l_sdData}\0-RawOutput\food_observations.dta", replace

*check optional modules
clear all
use "${l_sdData}\0-RawOutput\panel_dashboard_formatted", clear
merge 1:m parent_key using "${l_sdData}\0-RawOutput\raw food.dta"
keep if erelevanceyn==0 | erelevanceyn==1
tab treat eitem_module

*check treatment bias in interview length and items consumed
clear all
use "${l_sdData}\0-RawOutput\panel_dashboard_formatted", clear
drop if interview_duration>240
mean interview_duration, over(treat)
clear all
use "${l_sdData}\0-RawOutput\panel_dashboard_formatted", clear
mean return_yn, over(treat)
merge 1:m parent_key using "${l_sdData}\0-RawOutput\raw food.dta"
keep if erelevanceyn==0 | erelevanceyn==1
mean erelevanceyn, over(treat)
