* This file:
	* Aggregates nonmissing rows
	* Ensures each household has one household head
	* Identify and drop duplicates
	* Drop unnecessary variables and order the variables alphabetically

*Drop empty rows in hhm data
*Merge non-missing values from all other sets of raw data
merge m:1 parent_key using "${gsdData}/0-RawTemp/nonmissing_hhq.dta", keep(match master) nogenerate
merge m:1 parent_key using "${gsdData}/0-RawTemp/nonmissing_hhm.dta", keep(match master) nogenerate
merge m:1 parent_key using "${gsdData}/0-RawTemp/nonmissing_food.dta", keep(match master) nogenerate
merge m:1 parent_key using "${gsdData}/0-RawTemp/nonmissing_nonfood.dta", keep(match master) nogenerate
merge m:1 parent_key using "${gsdData}/0-RawTemp/nonmissing_livestock.dta", keep(match master) nogenerate
merge m:1 parent_key using "${gsdData}/0-RawTemp/nonmissing_assets.dta", keep(match master) nogenerate
*Aggregate non-missing values for each household
gen rownonmiss = rownonmiss_hhq + rownonmiss_hhm + rownonmiss_food + rownonmiss_nonfood + rownonmiss_livestock + rownonmiss_assets
*Drop empty rows in hhm data
drop if rownonmiss_hhm == 0
	
*Extract household member IDs
rename key member_key
gen hhmid = substr(member_key,strpos(member_key,"[")+1,strpos(member_key,"]")-strpos(member_key,"[")-1)
destring hhmid, replace
label var hhmid "Household member unique ID"
sort parent_key hhmid
order parent_key hhmid

*Removing leading and trailing blanks and converting the name variables to upper.
replace rhhm_name = strtrim(rhhm_name)
replace rhhm_name = upper(rhhm_name)

*Ensure each observation has a rhhm_name value - Verification: Observations without a rhhm_name have missing data on all variables.
ds parent_key hhmid rhhm_ishead rhhm_add rhhm_skip rhhm_last pos member_key setofhhm* rownonmiss*, not
foreach var of varlist `r(varlist)' {
	tab `var' if missing(rhhm_name)
	assert r(N) == 0
}
drop if missing(rhhm_name)

*Drop household respondents who have an empty "add" row or an additional (and empty) "skip" row
*First drop if add is equal to 0
drop if rhhm_add == 0
*Identify whether any HHs did not have a last member selected
bysort parent_key: egen sumlast = sum(rhhm_last)
assert sumlast == 1
save "${gsdTemp}/preverifyhhm.dta", replace
*Verifying that the household head names are the same as the household head names in hhq.dta
use "${gsdData}/0-RawOutput/hhq.dta", clear
keep parent_key hhh_name
merge 1:m parent_key using "${gsdTemp}/preverifyhhm.dta", keep(match) nogen
*There are 90 parent_keys in the hhm.dta that do not match with the parent_keys in the cleaned hhq.dta. These are the parent_keys dropped during the cleaning of hhq.dta.
*hhm.dta already did not have the 24 interviews conducted as exams, and did not have the interview for which there was no one at home in hhq.dta and the interview was dropped in cleaning.
bysort parent_key: egen sumhead = sum(rhhm_ishead)
replace rhhm_ishead = 1 if rhhm_name == hhh_name & sumhead == 0
bysort parent_key: egen sumhead1 = sum(rhhm_ishead)
duplicates tag parent_key rhhm_name if rhhm_ishead == 1, gen (tag)
drop if rhhm_skip == 1 & tag == 1 
bysort parent_key: egen sumhead2 = sum(rhhm_ishead)
*Verifying that each household has only one household head.
assert sumhead2 == 1
*Verifying each household has a household head name
assert !missing(hhh_name)
assert rhhm_name == hhh_name if rhhm_ishead == 1

*Set age to missing for household heads who are recorded as 17 years old or younger
tab hhm_age if hhm_age < 18 & rhhm_ishead == 1
replace hhm_age = . if hhm_age < 18 & rhhm_ishead == 1 & hhm_age != . & rhhm_ishead != .

*Next drop "skip" rows for HHs that had a last member selected - I have removed the lst member selected condition.
egen data = rownonmiss(*), strok
list data if rhhm_skip == 1
drop if rhhm_skip == 1
drop rhhm_skip rhhm_add rhhm_last sumlast sumhead*

** Identify potential duplicates
ds hhmid member_key pos, not
duplicates drop `r(varlist)' , force

*Generate number of household members per house
bysort parent_key: gen nhhm = _N

*Tag potential duplicate #1: records with identical parentkey, name, and age
duplicates tag parent_key rhhm_name hhm_age if !missing(rhhm_name) & !missing(hhm_age) , gen(tag1)
*Manually check duplicates and drop the observation with less information
egen duplicate_group_1 = group(parent_key) if tag1 == 1
bysort duplicate_group_1: egen min_data = min(data)
drop if data == min_data & tag1 == 1 
*As one of the duplicate entries were for a household head, we assign rhhm_ishead = 1 for that the leftover duplicate entry.
replace rhhm_ishead = 1 if parent_key == "uuid:7bd4e010-e251-41b2-b8d2-0f520309c926" & member_key == "uuid:7bd4e010-e251-41b2-b8d2-0f520309c926/mod_b-hhm[5]"
*Tag potential duplicate #2: records with identical parentkey and name
duplicates tag parent_key rhhm_name hhm_relation hhm_gender if !missing(rhhm_name) & !missing(hhm_gender), gen(tag2)
tab tag2
*Tag groups within duplicate type #2
egen duplicate_group_2 = group(parent_key rhhm_name hhm_relation hhm_gender) if tag2 == 1
*There are 39 pairs of duplicates on the basis of parent_key and rhhm_name
*There are 86 variables in the dataset. Finding out how many data points match across the pairs of potential duplicates.
gen match = 0
sort duplicate_group_2
ds
bysort duplicate_group_2: gen n = _n
ds hhmid pos member_key setofhhm rownonmiss* tag* duplicate*, not
foreach var in `r(varlist)' { 
	replace match = match + 1 if `var'[_n] == `var'[_n+1] & n == 1 & !missing(`var'[_n])
}
*Manual checking shows that the tagged potential duplicates do not seem to be true duplicates.
drop tag2 duplicate_group_2 match n
*Tag potential duplicate #3: households with identical rosters, identified by first finding household heads with identical names
bysort rhhm_name: egen hhhn = sum(rhhm_ishead)
list rhhm_name if hhhn>1
egen group_name = group(rhhm_name) if hhhn > 1
*There are 6 rhhm_enames that appear as household heads more than once in the table. 
gen hh_group = group_name if !missing(group_name) & rhhm_ishead == 1
bysort parent_key: egen hh_group1 = max(hh_group) 
*Now compare household rosters for households with identical household head names and household sizes
bysort hh_group: gen n = _n if !missing(hh_group)
*Comparing household sizes.
gen match = 1 if nhhm[_n] == nhhm[_n+1] & n == 1 
bysort hh_group: egen match1 = max(match)
bysort parent_key: egen match2 = max(match1) 
sort hh_group1 parent_key
list hh_group1 parent_key rhhm_name rownonmiss if match2 == 1
*There are two households with the same household head name and the size of household. However manual check shows that the names of other household members are different.
drop match* tag* group_name hh_group* hhhn n min_data duplicate* nhhm data

*Regenerate nhhm variable after the cleaning of data.
bysort parent_key: gen nhhm = _N

*Correct variable hhm_relation:
* This observation was duplicate and in the duplicate observation. The observation with more information was kept. However, the relationship was wrongly specified in that observation.
replace hhm_relation = . if parent_key == "uuid:7bd4e010-e251-41b2-b8d2-0f520309c926"
* Other 4 entries observations are wrong and should be replaced with missing. These are wrong as due to error in coding, hhh_name remained empty if no alternate household head was selected and the question was asked about the household head too.
replace hhm_relation = . if parent_key == "uuid:2204a607-acf4-4e5b-a1b8-2a65d1817ae5"
replace hhm_relation = . if parent_key == "uuid:6c0bf6a5-58aa-4e50-a66f-dc01cea2c4bc"
replace hhm_relation = . if parent_key == "uuid:ccc4d781-c0b6-417f-9a49-50697fc7b3d6"
replace hhm_relation = . if parent_key == "uuid:d59b2f27-5de6-441c-9094-658b77a94841"

*Cleaning of Occupations:
*A high level of subjectivity is introduced into the data due to the need of classifying the specified occupations into the already defined categories.
replace hhm_occ_lev1 = 9 if member_key == "uuid:00ebb7f7-8be5-4812-adb2-60b8270dfa59/mod_b-hhm[1]"
replace hhm_occ_elem = 94 if member_key == "uuid:00ebb7f7-8be5-4812-adb2-60b8270dfa59/mod_b-hhm[1]"
replace hhm_occ_lev1 = 8 if member_key == "uuid:0b3c1186-1067-4535-a4a6-09862243db00/mod_b-hhm[2]"
replace hhm_occ_plant = 83 if member_key == "uuid:0b3c1186-1067-4535-a4a6-09862243db00/mod_b-hhm[2]"
replace hhm_occ_lev1 = 7 if member_key =="uuid:0c224916-a596-4086-9df7-df7333c44e75/mod_b-hhm[2]"
replace hhm_occ_craft = 72 if member_key == "uuid:0c224916-a596-4086-9df7-df7333c44e75/mod_b-hhm[2]"
replace hhm_occ_lev1 = 2 if member_key == "uuid:0c224916-a596-4086-9df7-df7333c44e75/mod_b-hhm[5]"
replace hhm_occ_prof = 24 if member_key == "uuid:0c224916-a596-4086-9df7-df7333c44e75/mod_b-hhm[5]"
replace hhm_occ_lev1 = 10 if member_key == "uuid:0fe3952a-462b-475b-99c3-61f5883e134c/mod_b-hhm[1]"
replace hhm_occ_forces = 101 if member_key == "uuid:0fe3952a-462b-475b-99c3-61f5883e134c/mod_b-hhm[1]"
replace hhm_occ_lev1 = 1 if member_key == "uuid:111e645c-e69a-4d08-b6e1-69c990b85afb/mod_b-hhm[1]"
replace hhm_occ_mgr = 12 if member_key == "uuid:111e645c-e69a-4d08-b6e1-69c990b85afb/mod_b-hhm[1]"
replace hhm_occ_lev1 = 1 if member_key == "uuid:1359fd60-a8c0-4589-9f9a-4d40372adc13/mod_b-hhm[3]"
replace hhm_occ_mgr = 12 if member_key == "uuid:1359fd60-a8c0-4589-9f9a-4d40372adc13/mod_b-hhm[3]"
replace hhm_occ_lev1 = 9 if member_key == "uuid:196fa8d5-c92e-494d-a0a9-3bef3114e463/mod_b-hhm[1]"
replace hhm_occ_elem = 91 if member_key == "uuid:196fa8d5-c92e-494d-a0a9-3bef3114e463/mod_b-hhm[1]"
replace hhm_occ_lev1 = 9 if member_key == "uuid:196fa8d5-c92e-494d-a0a9-3bef3114e463/mod_b-hhm[4]"
replace hhm_occ_elem = 91 if member_key == "uuid:196fa8d5-c92e-494d-a0a9-3bef3114e463/mod_b-hhm[4]"
replace hhm_occ_lev1 = 9 if member_key == "uuid:1ba34349-831e-452d-b578-39f3431a5faa/mod_b-hhm[14]"
replace hhm_occ_elem = 94 if member_key == "uuid:1ba34349-831e-452d-b578-39f3431a5faa/mod_b-hhm[14]"
replace hhm_occ_lev1 = 5 if member_key == "uuid:1ca1c56c-49e6-493d-8b96-d8133bc3a553/mod_b-hhm[6]"
replace hhm_occ_service = 52 if member_key == "uuid:1ca1c56c-49e6-493d-8b96-d8133bc3a553/mod_b-hhm[6]"
replace hhm_occ_lev1 = 1 if member_key == "uuid:1e413911-3aac-411a-a79f-950a19e31005/mod_b-hhm[5]"
replace hhm_occ_mgr = 12 if member_key == "uuid:1e413911-3aac-411a-a79f-950a19e31005/mod_b-hhm[5]"
replace hhm_occ_lev1 = 2 if member_key == "uuid:1f60d6c4-881a-42c9-bdac-4238739672a7/mod_b-hhm[8]"
replace hhm_occ_prof = 25 if member_key == "uuid:1f60d6c4-881a-42c9-bdac-4238739672a7/mod_b-hhm[8]"
replace hhm_occ_lev1 = 7 if member_key =="uuid:2196d821-9985-4976-aeb3-97d60b69c4e7/mod_b-hhm[15]"
replace hhm_occ_craft = 75 if member_key == "uuid:2196d821-9985-4976-aeb3-97d60b69c4e7/mod_b-hhm[15]"
replace hhm_occ_lev1 = 6 if member_key =="uuid:26ae7f02-a222-427e-9582-0efaae029e72/mod_b-hhm[5]"
replace hhm_occ_skilled = 63 if member_key == "uuid:26ae7f02-a222-427e-9582-0efaae029e72/mod_b-hhm[5]"
replace hhm_occ_lev1 = 10 if member_key == "uuid:297aac18-4e1c-4284-9c14-2b3489699581/mod_b-hhm[2]"
replace hhm_occ_forces = 101 if member_key == "uuid:297aac18-4e1c-4284-9c14-2b3489699581/mod_b-hhm[2]"
replace hhm_occ_lev1 = 2 if member_key == "uuid:2a24940b-6449-4a9c-8ea0-b3ceb9642aee/mod_b-hhm[4]"
replace hhm_occ_prof = 23 if member_key == "uuid:2a24940b-6449-4a9c-8ea0-b3ceb9642aee/mod_b-hhm[4]"
replace hhm_occ_lev1 = 2 if member_key == "uuid:35dc1916-fa2b-42f6-a05e-794c2e1d4cb6/mod_b-hhm[7]"
replace hhm_occ_prof = 25 if member_key == "uuid:35dc1916-fa2b-42f6-a05e-794c2e1d4cb6/mod_b-hhm[7]"
replace hhm_occ_lev1 = 1 if member_key == "uuid:3783acfe-f014-471c-8611-52cd6e7a60ad/mod_b-hhm[3]"
replace hhm_occ_mgr = 14 if member_key == "uuid:3783acfe-f014-471c-8611-52cd6e7a60ad/mod_b-hhm[3]"
replace hhm_occ_lev1 = 5 if member_key == "uuid:386933ff-7466-45e8-9329-76110db8b98f/mod_b-hhm[9]"
replace hhm_occ_service = 54 if member_key == "uuid:386933ff-7466-45e8-9329-76110db8b98f/mod_b-hhm[9]"
replace hhm_occ_lev1 = 2 if member_key == "uuid:3b7d37b2-defd-4d73-a995-14ab6a725ac7/mod_b-hhm[2]"
replace hhm_occ_prof = 24 if member_key == "uuid:3b7d37b2-defd-4d73-a995-14ab6a725ac7/mod_b-hhm[2]"
replace hhm_occ_lev1 = 2 if member_key == "uuid:3e82a2f2-611c-499d-b845-2302eef7aa74/mod_b-hhm[6]"
replace hhm_occ_prof = 22 if member_key == "uuid:3e82a2f2-611c-499d-b845-2302eef7aa74/mod_b-hhm[6]"
replace hhm_occ_lev1 = 8 if member_key == "uuid:494109fa-c94c-404d-9acb-ee5d443a6edd/mod_b-hhm[2]"
replace hhm_occ_plant = 83 if member_key == "uuid:494109fa-c94c-404d-9acb-ee5d443a6edd/mod_b-hhm[2]"
replace hhm_occ_lev1 = 6 if member_key =="uuid:4a68e1bd-bcc7-45e5-a2dc-8c8ad4f7cd09/mod_b-hhm[7]"
replace hhm_occ_skilled = 63 if member_key == "uuid:4a68e1bd-bcc7-45e5-a2dc-8c8ad4f7cd09/mod_b-hhm[7]"
replace hhm_occ_lev1 = 9 if member_key == "uuid:4ca3a6ee-bed9-4f50-ae53-7df1a3b60631/mod_b-hhm[9]"
replace hhm_occ_elem = 92 if member_key == "uuid:4ca3a6ee-bed9-4f50-ae53-7df1a3b60631/mod_b-hhm[9]"
replace hhm_occ_lev1 = 7 if member_key =="uuid:4ca3a6ee-bed9-4f50-ae53-7df1a3b60631/mod_b-hhm[10]"
replace hhm_occ_craft = 75 if member_key == "uuid:4ca3a6ee-bed9-4f50-ae53-7df1a3b60631/mod_b-hhm[10]"
replace hhm_occ_lev1 = 5 if member_key == "uuid:5d2a354b-fddf-4c37-b310-5421aaf87e9d/mod_b-hhm[13]"
replace hhm_occ_service = 52 if member_key == "uuid:5d2a354b-fddf-4c37-b310-5421aaf87e9d/mod_b-hhm[13]"
replace hhm_occ_lev1 = 5 if member_key == "uuid:62837aa9-c189-4f5c-9429-c8bdce2c048c/mod_b-hhm[9]"
replace hhm_occ_service = 52 if member_key == "uuid:62837aa9-c189-4f5c-9429-c8bdce2c048c/mod_b-hhm[9]"
replace hhm_occ_lev1 = 6 if member_key =="uuid:67c6dbae-e543-42c6-b2df-7e82e38ccc4a/mod_b-hhm[2]"
replace hhm_occ_skilled = 63 if member_key == "uuid:67c6dbae-e543-42c6-b2df-7e82e38ccc4a/mod_b-hhm[2]"
replace hhm_occ_lev1 = 5 if member_key == "uuid:6b971826-fdb3-4436-8da7-4d72f3b75c3c/mod_b-hhm[1]"
replace hhm_occ_service = 54 if member_key == "uuid:6b971826-fdb3-4436-8da7-4d72f3b75c3c/mod_b-hhm[1]"
replace hhm_occ_lev1 = 8 if member_key == "uuid:704399c1-c0b2-4229-8806-958e065ea189/mod_b-hhm[1]"
replace hhm_occ_plant = 83 if member_key == "uuid:704399c1-c0b2-4229-8806-958e065ea189/mod_b-hhm[1]"
replace hhm_occ_lev1 = 5 if member_key == "uuid:78e09996-d1a0-4c02-b753-499b092210d7/mod_b-hhm[2]"
replace hhm_occ_service = 52 if member_key == "uuid:78e09996-d1a0-4c02-b753-499b092210d7/mod_b-hhm[2]"
replace hhm_occ_lev1 = 9 if member_key == "uuid:79f79c37-39ea-4c2b-9e8c-cf660b9570ad/mod_b-hhm[10]"
replace hhm_occ_elem = 91 if member_key == "uuid:79f79c37-39ea-4c2b-9e8c-cf660b9570ad/mod_b-hhm[10]"
replace hhm_occ_lev1 = 7 if member_key =="uuid:7bcad066-8a60-4359-b073-990c08c80dca/mod_b-hhm[8]"
replace hhm_occ_craft = 75 if member_key == "uuid:7bcad066-8a60-4359-b073-990c08c80dca/mod_b-hhm[8]"
replace hhm_occ_lev1 = 10 if member_key == "uuid:85e42151-c8fc-4310-8ae4-7662c45e9e5f/mod_b-hhm[1]"
replace hhm_occ_forces = 101 if member_key == "uuid:85e42151-c8fc-4310-8ae4-7662c45e9e5f/mod_b-hhm[1]"
replace hhm_occ_lev1 = 10 if member_key == "uuid:8b0bfb12-b636-416a-9cbf-f89a22cb265b/mod_b-hhm[2]"
replace hhm_occ_forces = 101 if member_key == "uuid:8b0bfb12-b636-416a-9cbf-f89a22cb265b/mod_b-hhm[2]"
replace hhm_occ_lev1 = 10 if member_key == "uuid:8b0bfb12-b636-416a-9cbf-f89a22cb265b/mod_b-hhm[1]"
replace hhm_occ_forces = 101 if member_key == "uuid:8b0bfb12-b636-416a-9cbf-f89a22cb265b/mod_b-hhm[1]"
replace hhm_occ_lev1 = 10 if member_key == "uuid:a5cf1ea0-f555-41c4-9eca-d1edf0eccfc6/mod_b-hhm[2]"
replace hhm_occ_forces = 101 if member_key == "uuid:a5cf1ea0-f555-41c4-9eca-d1edf0eccfc6/mod_b-hhm[2]"
replace hhm_occ_lev1 = 10 if member_key == "uuid:c9c54e62-a765-493d-9d68-ce4e09736ced/mod_b-hhm[1]"
replace hhm_occ_forces = 101 if member_key == "uuid:c9c54e62-a765-493d-9d68-ce4e09736ced/mod_b-hhm[1]"
replace hhm_occ_lev1 = 6 if member_key =="uuid:8a452900-ffb7-4a7f-b76f-8088b12aebc0/mod_b-hhm[3]"
replace hhm_occ_skilled = 63 if member_key == "uuid:8a452900-ffb7-4a7f-b76f-8088b12aebc0/mod_b-hhm[3]"
replace hhm_occ_lev1 = 6 if member_key =="uuid:99be1229-ceb6-4b79-939b-44132978a528/mod_b-hhm[10]"
replace hhm_occ_skilled = 63 if member_key == "uuid:99be1229-ceb6-4b79-939b-44132978a528/mod_b-hhm[10]"
replace hhm_occ_lev1 = 6 if member_key =="uuid:e0a4a3a8-c2ed-4392-8eba-ef24cd421281/mod_b-hhm[3]"
replace hhm_occ_skilled = 63 if member_key == "uuid:e0a4a3a8-c2ed-4392-8eba-ef24cd421281/mod_b-hhm[3]"
replace hhm_occ_lev1 = 6 if member_key =="uuid:e5d37db6-08ee-4c18-bbf5-69b09f8f68bf/mod_b-hhm[11]"
replace hhm_occ_skilled = 63 if member_key == "uuid:e5d37db6-08ee-4c18-bbf5-69b09f8f68bf/mod_b-hhm[11]"
replace hhm_occ_lev1 = 8 if member_key == "uuid:8d46611e-369d-4536-aece-e50ca5f8b6c0/mod_b-hhm[3]"
replace hhm_occ_plant = 83 if member_key == "uuid:8d46611e-369d-4536-aece-e50ca5f8b6c0/mod_b-hhm[3]"
replace hhm_occ_lev1 = 8 if member_key == "uuid:d469a236-a125-4d7b-a21c-bc02039116c4/mod_b-hhm[1]"
replace hhm_occ_plant = 83 if member_key == "uuid:d469a236-a125-4d7b-a21c-bc02039116c4/mod_b-hhm[1]"
replace hhm_occ_lev1 = 8 if member_key == "uuid:dbb5f106-4eaa-43b0-9d07-fd9cfe88c689/mod_b-hhm[1]"
replace hhm_occ_plant = 83 if member_key == "uuid:dbb5f106-4eaa-43b0-9d07-fd9cfe88c689/mod_b-hhm[1]"
replace hhm_occ_lev1 = 7 if member_key =="uuid:974e844c-9ea5-47c6-a9be-116a12797a96/mod_b-hhm[6]"
replace hhm_occ_craft = 75 if member_key == "uuid:974e844c-9ea5-47c6-a9be-116a12797a96/mod_b-hhm[6]"
replace hhm_occ_lev1 = 7 if member_key =="uuid:9841dc6f-253b-4548-8324-f57cfa4ccd96/mod_b-hhm[2]"
replace hhm_occ_craft = 75 if member_key == "uuid:9841dc6f-253b-4548-8324-f57cfa4ccd96/mod_b-hhm[2]"
replace hhm_occ_lev1 = 7 if member_key =="uuid:c0f85d08-6fdc-4cd1-8e24-34543dd66255/mod_b-hhm[5]"
replace hhm_occ_craft = 75 if member_key == "uuid:c0f85d08-6fdc-4cd1-8e24-34543dd66255/mod_b-hhm[5]"
replace hhm_occ_lev1 = 7 if member_key =="uuid:c69d6b4f-2d2a-4980-a439-f835573d2659/mod_b-hhm[8]"
replace hhm_occ_craft = 75 if member_key == "uuid:c69d6b4f-2d2a-4980-a439-f835573d2659/mod_b-hhm[8]"
replace hhm_occ_lev1 = 7 if member_key =="uuid:c69d6b4f-2d2a-4980-a439-f835573d2659/mod_b-hhm[9]"
replace hhm_occ_craft = 75 if member_key == "uuid:c69d6b4f-2d2a-4980-a439-f835573d2659/mod_b-hhm[9]"
replace hhm_occ_lev1 = 7 if member_key =="uuid:e42831a4-870e-43cb-b53b-7c4d6a2e5f60/mod_b-hhm[10]"
replace hhm_occ_craft = 75 if member_key == "uuid:e42831a4-870e-43cb-b53b-7c4d6a2e5f60/mod_b-hhm[10]"
replace hhm_occ_lev1 = 7 if member_key =="uuid:e42831a4-870e-43cb-b53b-7c4d6a2e5f60/mod_b-hhm[9]"
replace hhm_occ_craft = 75 if member_key == "uuid:e42831a4-870e-43cb-b53b-7c4d6a2e5f60/mod_b-hhm[9]"
replace hhm_occ_lev1 = 7 if member_key =="uuid:e5d37db6-08ee-4c18-bbf5-69b09f8f68bf/mod_b-hhm[2]"
replace hhm_occ_craft = 75 if member_key == "uuid:e5d37db6-08ee-4c18-bbf5-69b09f8f68bf/mod_b-hhm[2]"
replace hhm_occ_lev1 = 7 if member_key =="uuid:e82f9193-799f-4461-ac89-552caa348987/mod_b-hhm[2]"
replace hhm_occ_craft = 75 if member_key == "uuid:e82f9193-799f-4461-ac89-552caa348987/mod_b-hhm[2]"
replace hhm_occ_lev1 = 7 if member_key =="uuid:e82f9193-799f-4461-ac89-552caa348987/mod_b-hhm[8]"
replace hhm_occ_craft = 75 if member_key == "uuid:e82f9193-799f-4461-ac89-552caa348987/mod_b-hhm[8]"
replace hhm_occ_lev1 = 9 if member_key == "uuid:981f6b1c-ba72-4d43-a3b8-e83aabba60b7/mod_b-hhm[5]"
replace hhm_occ_elem = 93 if member_key == "uuid:981f6b1c-ba72-4d43-a3b8-e83aabba60b7/mod_b-hhm[5]"
replace hhm_occ_lev1 = 1 if member_key == "uuid:9bb5c070-c923-41b6-827a-de315031e89d/mod_b-hhm[2]"
replace hhm_occ_mgr = 12 if member_key == "uuid:9bb5c070-c923-41b6-827a-de315031e89d/mod_b-hhm[2]"
replace hhm_occ_lev1 = 1 if member_key == "uuid:ab1860a8-b0d7-46f5-8481-ee72c7849aab/mod_b-hhm[1]"
replace hhm_occ_mgr = 12 if member_key == "uuid:ab1860a8-b0d7-46f5-8481-ee72c7849aab/mod_b-hhm[1]"
replace hhm_occ_lev1 = 1 if member_key == "uuid:ac79d8f2-8339-4b16-838f-106128cca9b9/mod_b-hhm[1]"
replace hhm_occ_mgr = 12 if member_key == "uuid:ac79d8f2-8339-4b16-838f-106128cca9b9/mod_b-hhm[1]"
replace hhm_occ_lev1 = 5 if member_key == "uuid:bc4bd9c4-ea52-48a8-8136-933dc39bc990/mod_b-hhm[1]"
replace hhm_occ_service = 54 if member_key == "uuid:bc4bd9c4-ea52-48a8-8136-933dc39bc990/mod_b-hhm[1]"
replace hhm_occ_lev1 = 5 if member_key == "uuid:be352a5a-386b-47d4-b87f-ba84dc71f2e8/mod_b-hhm[20]"
replace hhm_occ_service = 54 if member_key == "uuid:be352a5a-386b-47d4-b87f-ba84dc71f2e8/mod_b-hhm[20]"
replace hhm_occ_lev1 = 9 if member_key == "uuid:c5354b81-f3be-4a1e-a6ff-410f44c3c7c7/mod_b-hhm[9]"
replace hhm_occ_elem = 93 if member_key == "uuid:c5354b81-f3be-4a1e-a6ff-410f44c3c7c7/mod_b-hhm[9]"
replace hhm_occ_lev1 = 9 if member_key == "uuid:c69d6b4f-2d2a-4980-a439-f835573d2659/mod_b-hhm[1]"
replace hhm_occ_elem = 93 if member_key == "uuid:c69d6b4f-2d2a-4980-a439-f835573d2659/mod_b-hhm[1]"
replace hhm_occ_lev1 = 9 if member_key == "uuid:c69d6b4f-2d2a-4980-a439-f835573d2659/mod_b-hhm[11]"
replace hhm_occ_elem = 93 if member_key == "uuid:c69d6b4f-2d2a-4980-a439-f835573d2659/mod_b-hhm[11]"
replace hhm_occ_lev1 = 9 if member_key == "uuid:d1ff71d2-692d-406a-98b7-c87173135527/mod_b-hhm[3]"
replace hhm_occ_elem = 93 if member_key == "uuid:d1ff71d2-692d-406a-98b7-c87173135527/mod_b-hhm[3]"
replace hhm_occ_lev1 = 9 if member_key == "uuid:e1b5c301-39aa-4011-96f5-d3c635ce9597/mod_b-hhm[1]"
replace hhm_occ_elem = 93 if member_key == "uuid:e1b5c301-39aa-4011-96f5-d3c635ce9597/mod_b-hhm[1]"
replace hhm_occ_lev1 = 9 if member_key == "uuid:fd41db8d-0044-49dc-9441-b782dc33fc7c/mod_b-hhm[4]"
replace hhm_occ_elem = 93 if member_key == "uuid:fd41db8d-0044-49dc-9441-b782dc33fc7c/mod_b-hhm[4]"
replace hhm_occ_lev1 = 9 if member_key == "uuid:0c224916-a596-4086-9df7-df7333c44e75/mod_b-hhm[3]"
replace hhm_occ_elem = 93 if member_key == "uuid:0c224916-a596-4086-9df7-df7333c44e75/mod_b-hhm[3]"
replace hhm_occ_lev1 = 9 if member_key == "uuid:64940ea6-eb7d-4d36-b8fc-c6561ff89bf1/mod_b-hhm[4]"
replace hhm_occ_elem = 93 if member_key == "uuid:64940ea6-eb7d-4d36-b8fc-c6561ff89bf1/mod_b-hhm[4]"
replace hhm_occ_lev1 = 9 if member_key == "uuid:bda72352-27bc-43b7-b6b5-4144f8f685ba/mod_b-hhm[6]"
replace hhm_occ_elem = 93 if member_key == "uuid:bda72352-27bc-43b7-b6b5-4144f8f685ba/mod_b-hhm[6]"
replace hhm_occ_lev1 = 2 if member_key == "uuid:13fcaf8f-9579-4ea9-a39a-f398f644a644/mod_b-hhm[8]"
replace hhm_occ_prof = 26 if member_key == "uuid:13fcaf8f-9579-4ea9-a39a-f398f644a644/mod_b-hhm[8]"
replace hhm_occ_lev1 = 2 if member_key == "uuid:214a4e4b-73e7-4a7e-ad60-781c661252e1/mod_b-hhm[12]"
replace hhm_occ_prof = 26 if member_key == "uuid:214a4e4b-73e7-4a7e-ad60-781c661252e1/mod_b-hhm[12]"
replace hhm_occ_lev1 = 2 if member_key == "uuid:4ac06ec4-c2ea-4dcd-b55a-d5e366caacd9/mod_b-hhm[1]"
replace hhm_occ_prof = 26 if member_key == "uuid:4ac06ec4-c2ea-4dcd-b55a-d5e366caacd9/mod_b-hhm[1]"
replace hhm_occ_lev1 = 2 if member_key == "uuid:e1b5c301-39aa-4011-96f5-d3c635ce9597/mod_b-hhm[2]"
replace hhm_occ_prof = 26 if member_key == "uuid:e1b5c301-39aa-4011-96f5-d3c635ce9597/mod_b-hhm[2]"
replace hhm_occ_lev1 = 5 if member_key == "uuid:c5354b81-f3be-4a1e-a6ff-410f44c3c7c7/mod_b-hhm[7]"
replace hhm_occ_service = 52 if member_key == "uuid:c5354b81-f3be-4a1e-a6ff-410f44c3c7c7/mod_b-hhm[7]"
replace hhm_occ_lev1 = 5 if member_key == "uuid:d5f5cffe-7e2a-4a55-b087-837617e60deb/mod_b-hhm[9]"
replace hhm_occ_service = 52 if member_key == "uuid:d5f5cffe-7e2a-4a55-b087-837617e60deb/mod_b-hhm[9]"
replace hhm_occ_lev1 = 5 if member_key == "uuid:fce8ea2f-4bc9-428a-9eec-d7c617adb17a/mod_b-hhm[9]"
replace hhm_occ_service = 52 if member_key == "uuid:fce8ea2f-4bc9-428a-9eec-d7c617adb17a/mod_b-hhm[9]"
replace hhm_occ_lev1 = 2 if member_key == "uuid:c9c6ed7e-8ef4-4fb5-987e-7ace2f41b19e/mod_b-hhm[2]"
replace hhm_occ_prof = 23 if member_key == "uuid:c9c6ed7e-8ef4-4fb5-987e-7ace2f41b19e/mod_b-hhm[2]"
replace hhm_occ_lev1 = 2 if member_key == "uuid:da38d654-8883-4202-b87d-c8fa5f54df22/mod_b-hhm[1]"
replace hhm_occ_prof = 23 if member_key == "uuid:da38d654-8883-4202-b87d-c8fa5f54df22/mod_b-hhm[1]"
replace hhm_occ_lev1 = 2 if member_key == "uuid:d1df5f4a-d7f5-4ee7-b4bb-138b4cd81c2a/mod_b-hhm[4]"
replace hhm_occ_prof = 24 if member_key == "uuid:d1df5f4a-d7f5-4ee7-b4bb-138b4cd81c2a/mod_b-hhm[4]"
replace hhm_occ_lev1 = 2 if member_key == "uuid:ee6a7fb5-be5a-472f-90be-7856245041dd/mod_b-hhm[1]"
replace hhm_occ_prof = 24 if member_key == "uuid:ee6a7fb5-be5a-472f-90be-7856245041dd/mod_b-hhm[1]"
replace hhm_occ_lev1 = 2 if member_key == "uuid:f2da067b-6b8a-4ef1-b77e-cca77be4118a/mod_b-hhm[1]"
replace hhm_occ_prof = 24 if member_key == "uuid:f2da067b-6b8a-4ef1-b77e-cca77be4118a/mod_b-hhm[1]"
replace hhm_occ_lev1 = 2 if member_key == "uuid:f8215464-5075-4adf-b539-1a4b1f8767e8/mod_b-hhm[1]"
replace hhm_occ_prof = 24 if member_key == "uuid:f8215464-5075-4adf-b539-1a4b1f8767e8/mod_b-hhm[1]"
replace hhm_occ_lev1 = 1 if member_key == "uuid:d1ff71d2-692d-406a-98b7-c87173135527/mod_b-hhm[6]"
replace hhm_occ_mgr = 14 if member_key == "uuid:d1ff71d2-692d-406a-98b7-c87173135527/mod_b-hhm[6]"
replace hhm_occ_lev1 = 7 if member_key =="uuid:d1ff71d2-692d-406a-98b7-c87173135527/mod_b-hhm[1]"
replace hhm_occ_craft = 75 if member_key == "uuid:d1ff71d2-692d-406a-98b7-c87173135527/mod_b-hhm[1]"
replace hhm_occ_lev1 = 7 if member_key =="uuid:dbd0d039-8547-483d-b020-20d05b24a590/mod_b-hhm[14]"
replace hhm_occ_craft = 75 if member_key == "uuid:dbd0d039-8547-483d-b020-20d05b24a590/mod_b-hhm[14]"
replace hhm_occ_lev1 = 7 if member_key =="uuid:e82f9193-799f-4461-ac89-552caa348987/mod_b-hhm[3]"
replace hhm_occ_craft = 75 if member_key == "uuid:e82f9193-799f-4461-ac89-552caa348987/mod_b-hhm[3]"
replace hhm_occ_lev1 = 7 if member_key =="uuid:fce8ea2f-4bc9-428a-9eec-d7c617adb17a/mod_b-hhm[8]"
replace hhm_occ_craft = 75 if member_key == "uuid:fce8ea2f-4bc9-428a-9eec-d7c617adb17a/mod_b-hhm[8]"
replace hhm_occ_lev1 = 6 if member_key =="uuid:dbd0d039-8547-483d-b020-20d05b24a590/mod_b-hhm[6]"
replace hhm_occ_skilled = 63 if member_key == "uuid:dbd0d039-8547-483d-b020-20d05b24a590/mod_b-hhm[6]"
replace hhm_occ_lev1 = 8 if member_key == "uuid:1f73262d-7974-4c4e-8004-449df8df91aa/mod_b-hhm[2]"
replace hhm_occ_plant = 83 if member_key == "uuid:1f73262d-7974-4c4e-8004-449df8df91aa/mod_b-hhm[2]"
replace hhm_occ_lev1 = 8 if member_key == "uuid:62837aa9-c189-4f5c-9429-c8bdce2c048c/mod_b-hhm[10]"
replace hhm_occ_plant = 83 if member_key == "uuid:62837aa9-c189-4f5c-9429-c8bdce2c048c/mod_b-hhm[10]"
replace hhm_occ_lev1 = 8 if member_key == "uuid:7a80d4c4-6bc4-4c17-bfa2-e8dffc637d0b/mod_b-hhm[2]"
replace hhm_occ_plant = 83 if member_key == "uuid:7a80d4c4-6bc4-4c17-bfa2-e8dffc637d0b/mod_b-hhm[2]"
replace hhm_occ_lev1 = 8 if member_key == "uuid:c3067d06-1d2d-4279-99aa-0a41ec1dceef/mod_b-hhm[1]"
replace hhm_occ_plant = 83 if member_key == "uuid:c3067d06-1d2d-4279-99aa-0a41ec1dceef/mod_b-hhm[1]"
replace hhm_occ_lev1 = 8 if member_key == "uuid:c40d11d2-2943-423a-a6fe-91d45f2f3b20/mod_b-hhm[16]"
replace hhm_occ_plant = 83 if member_key == "uuid:c40d11d2-2943-423a-a6fe-91d45f2f3b20/mod_b-hhm[16]"
replace hhm_occ_lev1 = 8 if member_key == "uuid:dbb5f106-4eaa-43b0-9d07-fd9cfe88c689/mod_b-hhm[4]"
replace hhm_occ_plant = 83 if member_key == "uuid:dbb5f106-4eaa-43b0-9d07-fd9cfe88c689/mod_b-hhm[4]"
replace hhm_occ_lev1 = 8 if member_key == "uuid:e82f9193-799f-4461-ac89-552caa348987/mod_b-hhm[1]"
replace hhm_occ_plant = 83 if member_key == "uuid:e82f9193-799f-4461-ac89-552caa348987/mod_b-hhm[1]"
replace hhm_occ_lev1 = 8 if member_key == "uuid:e82f9193-799f-4461-ac89-552caa348987/mod_b-hhm[1]"
replace hhm_occ_plant = 83 if member_key == "uuid:e82f9193-799f-4461-ac89-552caa348987/mod_b-hhm[1]"
replace hhm_occ_lev1 = 8 if member_key == "uuid:fb494352-77b0-458d-b8ec-394d06cb6c0e/mod_b-hhm[9]"
replace hhm_occ_plant = 83 if member_key == "uuid:fb494352-77b0-458d-b8ec-394d06cb6c0e/mod_b-hhm[9]"
replace hhm_occ_lev1 = 8 if member_key == "uuid:fb494352-77b0-458d-b8ec-394d06cb6c0e/mod_b-hhm[11]"
replace hhm_occ_plant = 83 if member_key == "uuid:fb494352-77b0-458d-b8ec-394d06cb6c0e/mod_b-hhm[11]"
*Drop unnecessary variables
drop nmigr *_calc* generated* setofhhm nid* rownonmiss* 

*Fix order

*Store names of variables with an item number
local nonsn "parent_key member_key hhmid"
ds `nonsn', not
*Save variable names and variable labels
foreach var of varlist `r(varlist)' {
	*Store variable labels
	local oldlabel : variable label `var'
	*Obtain questionnaire item numbers from variable labels
	local space = strpos(`"`oldlabel'"', " ")
	local sn = substr(`"`oldlabel'"', 1, `space' - 1)
	*Remove period from item numbers
	local sn = subinstr(`"`sn'"',".","",4)
	*Rename variables their respective item numbers
	rename `var' `sn'`var'
	}

*Reorder based on alphabetic-numeric order
order *, sequential

*Store names of variables with an item number
ds `nonsn', not
*Restore original variable names
foreach var of varlist `r(varlist)' {
	*Store variable labels
	local oldlabel : variable label `var'
	*Obtain questionnaire item numbers from variable labels
	local space = strpos(`"`oldlabel'"', " ")
	local sn = substr(`"`oldlabel'"', 1, `space' - 1)
	*Remove period from item numbers	
	local sn = subinstr(`"`sn'"',".","",4)
	*Create new variable names that do not include the item numbers incorporated earlier
	local newvar = subinstr("`var'","`sn'","",1)
	*Rename variables their earlier variable names
	rename `var' `newvar'
}

*Place key variables without an item number at front of variable list
order `nonsn', first


