*This do file cleans and standardizes the food consumption data.
	*	Add labels for the food consumption data using label files automatically created by the Survey CTO application
	*	Drop the household-level duplicates identified in the hhq and hhm data
clear all
set more off
set maxvar 10000
*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}		
use "${gsdDataRaw}/food.dta", clear
*Label food.dta file
do "${gsdDo}/0-4-food-1-label.do"

*Cleaning of food.dta
*Removing observations from food.dta that correspond to interviews that were dropped in the cleaning of hhq.dta and hhm.dta
merge m:1 parent_key using "${gsdData}/0-RawOutput/hhq.dta", keep(match) keepusing(parent_key) nogen
*There are a total of 1188 parent_keys in food.dta. One parent_key in hhq.dta did not match with food.dta. That interview seemed to have missing a significant number of modules.

*Clean up variable names
rename e* *

order parent_key itemid
sort parent_key itemid

*Checks:
assert item_recall == 7
assert cons_low == 1 if cons_quant < cons_min
assert cons_high == 1 if cons_quant > cons_max & !missing(cons_quant)
assert purc_low == 1 if purc_quant < purc_min
assert purc_high == 1 if purc_quant > purc_max & !missing(purc_quant)
assert pric_ssp == "error" if missing(pric_curr)
replace pric_ssp = "" if pric_ssp == "error"
destring pric_ssp, replace
assert cons_unit_options == 0 if !missing( cons_quant) & !missing( cons_unit)
assert cons_unit_options != 0 if missing(cons_quant) | missing(cons_unit)

*Dropping unnecessary variables:
drop itemnote cons_index v_avg item_recall setofrep_e

order parent_key itemid item_name
sort parent_key itemid
save "${gsdData}/0-RawOutput/food.dta", replace
