*This do file matches household observations from Wave1 to household observations in Wave2. It creates three 0-RawOutput data files.
*1) W1W2MatchedIDs.dta - Data file containing Identifiers for the matched observations to serve as a cross walk later. 
*2) W2unmatched.dta - Data file containing unmatched Wave2 observations
*3) W1unmatched.dta - Data file containing unmatched Wave1 observations
*This do file creates three temporary data files: 
*1) W1formatching.dta - Data file with Wave1 observations to be matched to Wave2
*2) W2formatching.dta - Data file with Wave2 observations to be matched to Wave1.
*3) W1W2Matched.xls for manual verification of matches.
*This do file uses an external file to bring in manual verification - W1W2Matched-Verified.xlsx.
clear all
set more off
set maxvar 10000
*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}
do "${gsdDo}/fDistance.do"
*Preparing Wave1 data for merge.
use "${gsdDataRaw}/Wave1/0-RawOutput/hhm.dta",clear
keep hhuid name gender age
sort hhuid name
bysort hhuid: gen hhmid = _n
bysort hhuid: gen hhsize = _N
*To simplify verification of matches, I limit the number of alphabetically arranged household members to 9. (Mean family size is 4.5)
drop if hhmid > 9 
reshape wide name gender age, i(hhuid) j(hhmid)
merge 1:1 hhuid using "${gsdDataRaw}/Wave1/0-RawOutput/hhq.dta", keep(match) nogen assert(match) keepusing(ea state urban loc* hh_id qr_resp_id* hhh_name hhr_name res_age)
*Wave2 was conducted only for Urban Areas
drop if urban==0
drop urban
*Clean hh_id's. 
foreach var of varlist *name* {
replace `var' = strtrim(`var')
replace `var' = upper(`var')
}
*Manually checking the household roster and changing hh_id's to correspond to hh_id's as in the listing form.
replace hh_id = "C12" if hhuid == "uuid:3d6989e0-462a-4511-b88c-e38c91a8bfd2"
replace hh_id = "C16" if hhuid == "uuid:210363f5-8471-4d6e-a101-94b4f1bcf322"
replace hh_id = "D3" if hhuid == "uuid:5fdb094b-73e1-44ce-b022-c4b9c5ddb3c7"
replace hh_id = "C16" if hhuid == "uuid:3e5b0198-fd87-46da-9fbb-3f6180cc5303"
replace hh_id = "B21" if hhuid == "uuid:df66449f-1d92-4e1e-badf-615d926067d6"
replace hh_id = "B20" if hhuid == "uuid:bef40d0e-3b56-436b-b0c8-552ae002c1fc"
replace hh_id = "A14" if hhuid == "uuid:5c09ab48-9a47-4194-88d6-d2258e5447d1"
replace hh_id = "B12" if hhuid == "uuid:2e7f89b9-044c-4dde-8d31-19d25c5220df"
replace hh_id = "B6" if hhuid == "uuid:12505414-99a0-4ac6-8b4b-5ba63ce69f77"
replace hh_id = "D2" if hhuid == "uuid:71415672-7fb0-4d69-a884-f32ff4e393bd"
replace hh_id = "C4" if hhuid == "uuid:4f7d75ea-d158-4870-9d83-c87a5fbb65cf"
replace hh_id = "B7" if hhuid == "uuid:182da8eb-69cf-453b-92f0-b4f3f97671a6"
replace hh_id = "A49" if hhuid == "uuid:cc17d988-9b99-43c0-ad78-e9e80b269cec"
*Cleaning qr_resp_id in Wave1 data. Qr_resp_ids in Wave1 has errors. 
*There are 9 observations with missing qr_resp_id's.
*44 barcodes in Eastern Equatoria were printed with 16 digits. I extract the 6 digit barcodes from the 16digits. 
*Enumerators had their own barcodes too. In 17 observations, Enumerators made the mistake of scanning their own barcodes.  
*qr_resp_id of "930001" is repeated 71 times. These are the wrongly printed barcodes for the state of Eastern Equatoria.
gen qr_resp_clean = qr_resp_id if length(qr_resp_id) == 6
replace qr_resp_clean = substr(qr_resp_id,11,6) if length(qr_resp_id) == 16
replace qr_resp_clean = "" if qr_resp_clean == "930001"
drop qr_resp_id
ren qr_resp_clean qr_resp_id
*There are 97 observations in Wave1 data without any qr_resp_id.(This is after replacing the qr_resp_id with "" for the wrongly printed values in Eastern Eqautoria.)
foreach x in state hhh_name hhr_name hhsize name* gender* *age* loc* {
	ren `x' `x'_W1
}
gen double ea_W1 = ea
format ea_W1 %14.0g
save "${gsdTemp}/W1formatching.dta", replace
*Limiting the data to Enumeration Areas that were surveyed both in Wave1 and Wave2
keep ea
duplicates drop
merge 1:m ea using "${gsdData}/0-RawOutput/hhq.dta", keep(match) nogen keepusing(parent_key qr_resp_id ea state loc* hh_id hhh_name hhr_name res_age)
*43 Enumeration Areas from urban areas of Wave1 are not revisited in Wave2 data.
*34 Enumeration Areas from Wave2 were new Enumeration Areas that were not previously visited in Wave1. These include the 15 Enumeration Areas in the Warrap State.
*In Wave1, 10 urban enumeration areas were surveyed for the three states of Northern Bahar-el-Ghazal, Lakes and Eastern Equatoria State.
*In Wave2, 20 urban enumeration areas were selected from each state. The first 15 were intended to be surveyed and 5 were used as replacements as needed.
*For these three states, 5 urban enumeration areas were selected for each state which were not part of the Wave1 sample. This accounts for 15 Enumeration areas not in the Wave1 sample.
*For the state of Western Bahr El Ghazal, 4 Enumeration areas that were in the Wave1 sample could not be interviewed in Wave2 due to security concerns, accounting for the remaining discrepancy of 4 enumeration areas.  
*Preparing Wave2 data for merge
save "${gsdTemp}/W2formatching.dta", replace
*A total of 793 observations need to be matched.
use "${gsdData}/0-RawOutput/hhm.dta", clear
keep parent_key rhhm_name hhm_age hhm_gender
ren (rhhm_name hhm_age hhm_gender) (name age gender)
sort parent_key name
bysort parent_key: gen hhmid = _n
bysort parent_key: gen hhsize = _N
drop if hhmid > 9
reshape wide name gender age, i(parent_key) j(hhmid)  
merge 1:1 parent_key using "${gsdTemp}/W2formatching.dta", keep(match) nogen
foreach x of varlist state hhh* hhr* hhsize name* gender* *age* loc*{
	ren `x' `x'_W2
}
gen double ea_W2 = ea
format ea_W2 %14.0g
foreach var of varlist *name* {
replace `var' = strtrim(`var')
replace `var' = upper(`var')
}
save "${gsdTemp}/W2formatching.dta", replace
********************************************************************************
*Merge Wave 2 Data with Wave 1 Data: 
********************************************************************************
*Matching between Wave2 Households and Wave1Households is done in 3 steps.
	* Merge using ea and hh_id of the respondent household
	* Merge using qr_resp_id: barcode of the respondent household
	* Match using hhhh_name (household head name) and hhr_name (household respondent name)
	* Verify using geographic coordinates and hhm_name (household member name)

*Match using ea and hh_id of the respondent household
use "${gsdTemp}/W1formatching.dta", clear
* We use m:m merge are two duplicate pairs of hh_id's in Wave2 and some duplicate pairs of hh_id's in Wave1 data.
merge m:m ea hh_id using "${gsdTemp}/W2formatching.dta", keep(match) gen(match)
*596 observations are matched based on hh_id
replace match = 1
*Verification:
fDistance loclatitude_W2 loclongitude_W2 loclatitude_W1 loclongitude_W1 vdistance
gen hhm_n=0
forvalues i = 1/9 {
	forvalues j = 1/9 {
		replace hhm_n = hhm_n+1 if name`j'_W1 == name`i'_W2 & name`j'_W1 != ""
}
}
sort ea hhh_name_W2 hhh_name_W1
*Manually verify the matches.
export excel ea hhh_name* vdistance hhm_n name1* gender1* age1* name2* gender2* age2* name3* gender3* age3* name4* gender4* age4* name5* gender5* age5* parent_key hhuid using "${gsdTemp}/W1W2Matched.xlsx", sheetmodify sheet("Match1") cell(B1) firstrow(variables)
*Manual verification is done in three steps:
*1) hhh_names are checked
*2) Distance between the households.
*3) Similarity in the household roster.
*In the excel sheet, a new variable MC_yes identifies whether the matches have been manually verified or not. In total, 563 matches have been verified to be true matches.
import excel using "${gsdDataRaw}/W1W2Matched-Verified.xlsx", sheet("Match1") firstrow clear
drop if MC_yes == 0 
save "${gsdTemp}/W1W2Matched.dta", replace 
keep parent_key hhuid
save "${gsdTemp}/W1W2MatchedIDs.dta", replace

*Preparing the Data for a second attempt on matching based on qr_resp_id
keep parent_key
merge 1:1 parent_key using "${gsdTemp}/W2formatching.dta", keep(using) nogen
save "${gsdTemp}/W2formatching.dta", replace
*There are 230 observations left to be matched.

*Preparing Wave1 data for matching on qr_resp_id
use "${gsdTemp}/W1W2MatchedIDs.dta", clear
keep hhuid
merge 1:1 hhuid using "${gsdTemp}/W1formatching.dta", keep(using) nogen
ren hh_id hh_id_W1
save "${gsdTemp}/W1formatching.dta", replace
*There are 36 observations in Wave1 data without any qr_resp_id.(This is after replacing the qr_resp_id with "" for the wrongly printed values in Eastern Eqautoria.)
drop if qr_resp_id == ""
*We are using 1:m because there are missing values of qr_resp_id in W2formatching.dta
merge 1:m qr_resp_id using "${gsdTemp}/W2formatching.dta", keep(match) gen(match)
replace match = 2
*60 observations are further matched based on qr_resp_id.
assert ea_W1 ==  ea_W2
*Verification:
fDistance loclatitude_W2 loclongitude_W2 loclatitude_W1 loclongitude_W1 vdistance
gen hhm_n=0
forvalues i = 1/9 {
	forvalues j = 1/9 {
		replace hhm_n = hhm_n+1 if name`j'_W1 == name`i'_W2 & name`j'_W1 != ""
}
}
sort ea hhh_name_W2
*Manually verify the matches
export excel ea hhh_name* vdistance hhm_n name1* gender1* age1* name2* gender2* age2* name3* gender3* age3* name4* gender4* age4* name5* gender5* age5* parent_key hhuid using "${gsdTemp}/W2W1Matched.xlsx", sheetmodify sheet("Match2") cell(B1) firstrow(variables)
*Manual verification is done in three steps:
*1) Households matched on qr_resp_id are checked on household head name.
*2) Distance between the households.
*3) Similarlity in the household roster.
*In the excel sheet, a new variable MC_yes identifies whether the matches have been manually verified or not. 
import excel using "${gsdDataRaw}/W1W2Matched-Verified.xlsx", sheet("Match2") firstrow clear 
drop if MC_yes == 0
*58 matches are manually verified to be true matches.
append using "${gsdTemp}/W1W2Matched.dta"
save "${gsdTemp}/W1W2Matched.dta" , replace
keep parent_key hhuid
save "${gsdTemp}/W1W2MatchedIDs.dta", replace

*Preparing the Data for a third attempt on matching based on Enumeration Area and household head name.
keep parent_key
merge 1:1 parent_key using "${gsdTemp}/W2formatching.dta", keep(using) nogen
ren (state_W2 hhh_name_W2) (state hhh_name)
save "${gsdTemp}/W2formatching.dta", replace
*172 observations are yet to be matched.

use "${gsdTemp}/W1W2MatchedIDs.dta", clear
keep hhuid
duplicates drop
merge 1:m hhuid using "${gsdTemp}/W1formatching.dta", keep(using) nogen
drop ea
ren (ea_W1 state_W1 hhh_name_W1) (ea state hhh_name)
save "${gsdTemp}/W1formatching.dta", replace
*We are using m:1 because there are two households with the same name for the household head in the same enumeration area in Wave1. 
*This observation does not seem to be a duplicate as the household roster differs.
merge m:1 ea hhh_name using "${gsdTemp}/W2formatching.dta", keep(match) gen(match)
*22 observations are further matched on qr_resp_id
replace match = 3
*Verifications for the match.
*There are no duplicate matches.
duplicates tag ea state hhh_name, gen(tag1)
assert tag1 == 0
*Checking the distance between the matched Wave2 and Wave1 observations
fDistance loclatitude_W2 loclongitude_W2 loclatitude_W1 loclongitude_W1 vdistance
*Checking the number of times member names are repeated across Wave2 and Wave1 observations.
gen hhm_n=0
forvalues i = 1/9 {
	forvalues j = 1/9 {
		replace hhm_n = hhm_n +1 if name`j'_W1 == name`i'_W2 & name`j'_W1 != ""
}
}
sort ea hhh_name
*Manually verify the matches.
export excel ea hhh_name* vdistance hhm_n name1* gender1* age1* name2* gender2* age2* name3* gender3* age3* name4* gender4* age4* name5* gender5* age5* parent_key hhuid hh_id* using "${gsdTemp}/W2W1Matched.xlsx", sheetmodify sheet("Match3") cell(B1) firstrow(variables)
import excel using "${gsdDataRaw}/W1W2Matched-Verified.xlsx", sheet("Match3") firstrow clear
drop if MC_yes == 0
*22 matches were manually verified to be true matches.
append using "${gsdTemp}/W1W2Matched.dta"
save "${gsdData}/0-RawOutput/W1W2Matched.dta", replace
keep parent_key hhuid
save "${gsdData}/0-RawOutput/W1W2MatchedIDs.dta", replace
*In total 643 households are matched.

*Saving unmatched observations.
keep parent_key
merge 1:1 parent_key using "${gsdTemp}/W2formatching.dta", keep(using) nogen
save "${gsdData}/0-RawOutput/W2unmatched.dta", replace

use "${gsdData}/0-RawOutput/W1W2MatchedIDs.dta", clear
keep hhuid
merge 1:m hhuid using "${gsdTemp}/W1formatching.dta", keep(using) nogen
save "${gsdData}/0-RawOutput/W1unmatched.dta", replace
