*This do file
	*	Checks for the balance of treatment
	*	Checks the timing of interviews
	*	Check the duration of interviews
	*	Check the distances between successive interviews conducted by the same enumerator
	*	Producing cumulative counts by team and enumerator
	*	Checking percentage of food shares by team and enumerator
*Check if filepaths have been established using init.do
clear all
set more off
set maxvar 10000
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}
use "${gsdData}/0-RawOutput/hhq.dta", clear
*Checking the balance of treatment
*create treat flags
     forvalues i = 1/4 {
          gen int treat`i'= treat==`i'
          }
tab treat
local goodvars "today_auto state ea enum hh_id hhsid_org treat treat*"
keep `goodvars'
order `goodvars'
la var state "State"
la var ea "EA"
la var today_auto "Date"
sort ea hhsid_org
export excel today_auto state ea enum hh_id hhsid treat* using "${gsdData}\0-RawOutput\HFSSS_Wave2_Consistencychecks.xlsx", sheet(interviews) sheetmod first(varl)
gen num_int=1
order num_int, before(hh_id)
collapse (first)today_auto state (sum) num_int treat1 treat2 treat3 treat4, by(ea)
order state
la var state "State"
la var ea "EA"
la var today_auto "Date"
la var num_int "Num of Interviews"
*label treat flags
     forvalues i = 1/4 {
          la var treat`i' "Treat`i'"
          }
ren ea s_ea
merge 1:1 s_ea using "${gsdDataRaw}/General/EA_master.dta", keep(match master)	assert(match) nogen	  
export excel "${gsdData}\0-RawOutput\HFSSS_Wave2_Consistencychecks.xlsx", sheet(summary) sheetmod first(varl)

*Checking timing and duration of interviews

*Calculate interview time.
use "${gsdData}/0-RawOutput/hhq.dta", clear
gen interview_duration=end_time-start_time
replace interview_duration=round(interview_duration/(60*1000))
order interview_duration
replace interview_duration=. if interview_duration>300
*Create manual labels for each month to facilitate the graphing in Excel
gen interview_count=1
gen date_dif=today_auto-today_manu
gen str3 today_auto_month=""
replace today_auto_month="Jan" if month(today_auto)==1
replace today_auto_month="Feb" if month(today_auto)==2
replace today_auto_month="Mar" if month(today_auto)==3
replace today_auto_month="Apr" if month(today_auto)==4
replace today_auto_month="May" if month(today_auto)==5
*Count how many interviews are replacement interviews
gen hhsid_replace_count=.
replace hhsid_replace_count=1 if hhsid==-1000
tab hhsid_replace_count
*create treat flags
     forvalues i = 1/4 {
          gen int treat`i'= treat==`i'
          }
*label treat flags
     forvalues i = 1/4 {
          la var treat`i' "Treat`i'"
          }
local goodvars "ea interview_count state enum_m today_auto today_manu date_dif start_time end_time interview_duration submissiondate hhsid hhsid_replace hhsid_org treat treat1 treat2 treat3 treat4 hh_id loclatitude loclongitude localtitude locaccuracy deviceid parent_key today_auto_month"
keep `goodvars'
order `goodvars'
sort ea hhsid_org
la var date_dif "Date difference between beginning of interviews"
la var interview_duration "Interview duration in minutes"
mean interview_duration, over(treat)
*Export raw dashboard data to "Interviews - Output" tab
export excel using "${gsdData}\0-RawOutput\HFSSS_Wave2_Consistencychecks.xlsx", sheetreplace sheet("Interviews - Output") first(varl) cell(A4)
*What was the duration of relatively short and long interviews?
*Generate interview start and end dates
gen start_date = dofc(start_time)
gen end_date = dofc(end_time)
format start_date end_date %tdCCYY-NN-DD 
*Generate interview duration in hours and days
gen duration = (end_time - start_time) / 3600000
gen duration_day = duration/24
label var duration "Duration (hrs)"
label var duration_day "Duration (days)"
*Generate indicator variable for same day interviews
gen sameday = .
replace sameday = 0 if start_date != end_date & start_date != . & end_date != .
replace sameday = 1 if start_date == end_date & start_date != . & end_date != .
tab sameday
*Graph very short (<=0.5 hours) and long (>= 7 days) interviews
set graphics off
hist duration if duration <= 0.5, freq start(0) width(0.025)
graph export "${gsdOutput}/duration_short.pdf", as(pdf) replace
hist duration_day if duration_day >= 7, freq xlabel(7(7)126) start(7)
graph export "${gsdOutput}/duration_long.pdf", as(pdf) replace
set graphics on
*Check if any interview submission times occurred before interview end time
list enum_m start_time end_time submissiondate if submissiondate < end_time
*Very small difference, might be due to network issues.

*What were the distances between successive interviews for each enumerator?
*First generate amount of overlapped time between successive interviews
sort enum_m start_time
by enum_m: gen overlap = (end_time[_n] - start_time[_n+1]) / 3600000
replace overlap = overlap / 24
replace overlap = 0 if overlap <= 0
*Next generate distances between successive interviews among each enumerator
do "${gsdDo}/fDistance.do"
sort enum start_time, stable
by enum_m: gen loclatitude_a = loclatitude[_n+1]
by enum_m: gen loclongitude_a = loclongitude[_n+1]
quietly fDistance loclatitude loclongitude loclatitude_a loclongitude_a dist_a
replace dist_a = dist_a / 1000
*Generate time difference between successive interviews among each enumerator
sort enum start_time, stable
by enum: gen timediff = (start_time[_n+1] - end_time[_n]) / 3600000
replace timediff = 0 if timediff < 0
*Look at time differences between interviews that were more than 200 kilometers apart
tab timediff dist_a if dist_a > 200 & dist_a != . & overlap == 0
*Time difference is substantial.
*Calculate implied travel speed (km/hr) between interviews
gen speed = dist_a / timediff
*List time differences for very long distances between successive interviews
sort speed
outfile enum dist_a timediff speed if dist_a > 200 & dist_a != . & overlap == 0 using "${gsdOutput}/tab_distance.txt", noquote wide replace
*Speeds are not high.
save "${gsdTemp}\hhq_consistencychecks.dta", replace

*CUMULATIVE COUNTS
*Cumulative interview count for the whole project
*Use formated data and create balanced time series; generate cumulative counts
gen today_auto_dow=dow(today_auto)
gen wBegin = today_auto-today_auto_dow
collapse (sum) interview_count, by(wBegin)
tsset wBegin, delta(7)
tsfill
gen interview_count_cumul=sum(interview_count)
*Label variables for output
la var wBegin "Week of data collection" 
la var interview_count "Nb of interviews completed"
la var interview_count_cumul "Nb of conducted interview - Cumulative"
format wBegin %td
*Export to dashboard excel file; modify only that tab
export excel using "${gsdData}\0-RawOutput\HFSSS_Wave2_Consistencychecks.xlsx", sheetmodify sheet("Graph 9 - Interv Whole Project") first(varl) cell(A4)

*Cumulative indicators by team
use "${gsdTemp}\hhq_consistencychecks.dta", clear
*Collapse by state; create balanced time series and cumulative counts
order state today_auto interview_count
collapse (sum) interview_count ea, by(state today_auto)
sort state today_auto
tsset state today_auto
tsfill, full
by state: gen interview_count_cumul=sum(interview_count)
by state: gen ea_count_cumul=sum(ea)

*Label variables for output
la var state "Team (state)"
la var today_auto "Day of data collection" 
la var interview_count "Nb of interviews completed"
la var interview_count_cumul "Nb of interviews completed - Cumulative"
la var ea "Nb of EAs completed"
la var ea_count_cumul "Nb of EAs completed - Cumulative"
export excel using "${gsdData}\0-RawOutput\HFSSS_Wave2_Consistencychecks.xlsx", sheetmodify sheet("Team - Output") first(varl) cell(A4)

*Generate Raw Food Scores:
*Use data from the food consumption module and calculate how many items were consumed from each module.
use "${gsdData}/0-RawOutput/food.dta", clear
merge m:1 parent_key using "${gsdData}/0-RawOutput/hhq.dta", keep(match) keepusing(treat) nogen
*Eliminate don't know and refused to respond answers.
replace relevanceyn=. if relevanceyn!=1
*Calculate number of items consumed for each module and collapse these counts by interview using parent_key.
forvalues i = 0/4 {
	gen mod`i'_cons=.
	replace mod`i'_cons=1 if item_module==`i' & relevanceyn==1
}
forvalues i = 0/4 {
	gen econs_quant_nonmiss`i'=.
	replace econs_quant_nonmiss`i'=1 if item_module==`i' & relevanceyn==1 & cons_quant!=.
}
collapse (sum) relevanceyn econs_quant_nonmiss? mod* ,by(parent_key treat)
*Calculate percentages of food items consumed for each module.
*Caluculate percentage of items consumed out of total items on each list.
gen pct_cons_allfood=relevanceyn/140
gen pct_cons_mod0=mod0_cons/33
gen pct_cons_mod1=mod1_cons/27
gen pct_cons_mod2=mod2_cons/26
gen pct_cons_mod3=mod3_cons/26
gen pct_cons_mod4=mod4_cons/28
egen pct_cons_optional=rowmax(pct_cons_mod1 pct_cons_mod2 pct_cons_mod3 pct_cons_mod4)
gen pct_econs_quant_nonmiss=(econs_quant_nonmiss0+econs_quant_nonmiss1+econs_quant_nonmiss2+econs_quant_nonmiss3+econs_quant_nonmiss4)/140
gen pct_nonmiss_mod0 = econs_quant_nonmiss0/33
gen pct_nonmiss_mod1 = econs_quant_nonmiss1/27
gen pct_nonmiss_mod2 = econs_quant_nonmiss2/26
gen pct_nonmiss_mod3 = econs_quant_nonmiss3/26
gen pct_nonmiss_mod4 = econs_quant_nonmiss4/28
*pct_nonmiss_optional refers to whatever optional module (treat) was used for that interview.
egen pct_nonmiss_optional=rowmax(pct_nonmiss_mod1 pct_nonmiss_mod2 pct_nonmiss_mod3 pct_nonmiss_mod4)
keep if relevanceyn==0 | relevanceyn==1
mean relevanceyn, over(treat)
*Save the food percentage scores for each interview. To be merged back in later.
save "${gsdData}\0-RawOutput\food_collapse.dta", replace

*Generate table with merged food score data; save for later use
merge 1:1 parent_key using "${gsdTemp}/hhq_consistencychecks.dta", keep(match) nogen
save "${gsdTemp}/hhq_foodscores.dta", replace

*3.4 Generate basic table summarizing all interviews by enumerator
*Collapse by enumerator-EA-phase and then identify how many EAs each enumerator visited in each state
use "${gsdTemp}\hhq_consistencychecks.dta", clear
collapse (first) state, by(enum_m ea)
tab enum_m state
tabout enum state using "${gsdOutput}/tab_eastate.txt", cells(freq) format(0c) clab(Freq.) append
use "${gsdTemp}/hhq_foodscores.dta", clear
collapse (sum) interview_count=interview_count number_of_EAs=ea treat1 treat2 treat3 treat4 (min) state first_date=today_auto (p50) med_pct_food_QC_all=pct_econs_quant_nonmiss med_intv_time=interview_duration med_pct_food_all=pct_cons_allfood med_pct_food_core=pct_cons_mod0 med_pct_food_opt=pct_cons_optional med_pct_food_QC_core=pct_nonmiss_mod0 med_pct_food_QC_opt=pct_nonmiss_optional (mean) mean_pct_food_QC_all=pct_econs_quant_nonmiss mean_pct_food_all=pct_cons_allfood mean_pct_food_core=pct_cons_mod0 mean_pct_food_opt=pct_cons_optional mean_pct_food_QC_core=pct_nonmiss_mod0 mean_pct_food_QC_opt=pct_nonmiss_optional (mean) mean_intv_time=interview_duration (min) min_intv_time=interview_duration (max) max_intv_time=interview_duration, by(enum_m)
format *int* %3.0f
sort enum_m

*Generate percentage indicators based on collpased counts
gen pct_treat1=treat1/interview_count
gen pct_treat2=treat2/interview_count
gen pct_treat3=treat3/interview_count
gen pct_treat4=treat4/interview_count

*Label variables for output
la var pct_treat1 "% interviews with treatment 1"
la var pct_treat2 "% interviews with treatment 2"
la var pct_treat3 "% interviews with treatment 3"
la var pct_treat4 "% interviews with treatment 4"

*Export to dashboard excel file; modify only that tab
order enum_m state first_date interview_count number_of_EAs med_pct_food_all med_pct_food_core med_pct_food_opt med_pct_food_QC_all med_pct_food_QC_core med_pct_food_QC_opt mean_pct_food_all mean_pct_food_core mean_pct_food_opt mean_pct_food_QC_all mean_pct_food_QC_core mean_pct_food_QC_opt med_intv_time mean_intv_time min_intv_time max_intv_time treat1 treat2 treat3 treat4 pct_treat1 pct_treat2 pct_treat3 pct_treat4
export excel using "${gsdData}\0-RawOutput\HFSSS_Wave2_Consistencychecks.xlsx", sheetmodify sheet("Enumerator - Output") first(varl) cell(A4)

*INDICATORS BY TEAM

*Indicators by team
use "${gsdTemp}/hhq_foodscores.dta", clear
*Collapse all relevant indicators by state (team) and sort by state
collapse (sum) interview_count=interview_count number_of_EAs=ea treat1 treat2 treat3 treat4 (min) first_date=today_auto (p50) med_pct_food_QC_all=pct_econs_quant_nonmiss med_intv_time=interview_duration med_pct_food_all=pct_cons_allfood med_pct_food_core=pct_cons_mod0 med_pct_food_opt=pct_cons_optional med_pct_food_QC_core=pct_nonmiss_mod0 med_pct_food_QC_opt=pct_nonmiss_optional (mean) mean_pct_food_QC_all=pct_econs_quant_nonmiss mean_pct_food_all=pct_cons_allfood mean_pct_food_core=pct_cons_mod0 mean_pct_food_opt=pct_cons_optional mean_pct_food_QC_core=pct_nonmiss_mod0 mean_pct_food_QC_opt=pct_nonmiss_optional (mean) mean_intv_time=interview_duration (min) min_intv_time=interview_duration (max) max_intv_time=interview_duration, by(state)
format *int* %3.0f
sort state

*Generate percentage indicators based on collpased counts
gen pct_treat1=treat1/interview_count
gen pct_treat2=treat2/interview_count
gen pct_treat3=treat3/interview_count
gen pct_treat4=treat4/interview_count

*Label variables for output and add state labels
la var state "State (team)"
la var pct_treat1 "% interviews with treatment 1"
la var pct_treat2 "% interviews with treatment 2"
la var pct_treat3 "% interviews with treatment 3"
la var pct_treat4 "% interviews with treatment 4"
order state first_date interview_count med_pct_food_all med_pct_food_core med_pct_food_opt med_pct_food_QC_all med_pct_food_QC_core med_pct_food_QC_opt med_intv_time mean_pct_food_QC_all mean_pct_food_all mean_pct_food_core mean_pct_food_opt mean_pct_food_QC_core mean_pct_food_QC_opt mean_intv_time min_intv_time max_intv_time treat1 treat2 treat3 treat4 pct_treat1 pct_treat2 pct_treat3 pct_treat4
export excel using "${gsdData}\0-RawOutput\HFSSS_Wave2_Consistencychecks.xlsx", sheetmodify sheet("Team - Output Food") first(varl) cell(A4)
	
